<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//sk_SK

$LANG=array();


$LANG['backup'][0]="Výpis SQL"; 
$LANG['backup'][1]="Výpis XML"; 
$LANG['backup'][11]="Veľkosť"; 
$LANG['backup'][13]="Zobraziť/Stiahnuť"; 
$LANG['backup'][16]="Prepísať aktuálnu databázu záložným súborom:"; 
$LANG['backup'][17]="Zmazať tento súbor"; 
$LANG['backup'][18]="Záloha databázy"; 
$LANG['backup'][19]="Teraz"; 
$LANG['backup'][21]="Súbor už existuje"; 
$LANG['backup'][22]="Nemôžem nájsť žiadne data"; 
$LANG['backup'][23]="Chyba Mysql začína na"; 
$LANG['backup'][24]="Automatické presmerovanie, inak kliknite"; 

$LANG['bookmark'][1]="záložka"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Zatiaľ nemáte uložené žiadne záložky."; 
$LANG['bookmark'][4]="Nová záložka"; 
$LANG['bookmark'][5]="Verejné záložky"; 
$LANG['bookmark'][6]="Východzie zobrazenie"; 

$LANG['buttons'][0]="Hľadať"; 
$LANG['buttons'][2]="Odoslať"; 
$LANG['buttons'][3]="Priradiť"; 
$LANG['buttons'][4]="Inštalovať"; 
$LANG['buttons'][5]="Odinštalovať"; 
$LANG['buttons'][6]="zmazať"; 
$LANG['buttons'][7]="Aktualizovať"; 
$LANG['buttons'][8]="Pridať"; 
$LANG['buttons'][9]="Pripojiť"; 
$LANG['buttons'][10]="Odpojiť"; 
$LANG['buttons'][11]="Nasledovný"; 
$LANG['buttons'][12]="Predošlý"; 
$LANG['buttons'][13]="Späť"; 
$LANG['buttons'][14]="Aktualizovať"; 
$LANG['buttons'][15]="Kalendár"; 
$LANG['buttons'][16]="Prázdny"; 
$LANG['buttons'][17]="Invertovať označenie"; 
$LANG['buttons'][18]="Označ všetko"; 
$LANG['buttons'][19]="Odznačiť všetko"; 
$LANG['buttons'][20]="Presunúť"; 
$LANG['buttons'][21]="Obnoviť"; 
$LANG['buttons'][22]="Vyčistiť"; 
$LANG['buttons'][23]="Zobraziť"; 
$LANG['buttons'][24]="Posun nahor"; 
$LANG['buttons'][25]="Posun nadol"; 
$LANG['buttons'][27]="Aktuálna strana v PDF"; 
$LANG['buttons'][28]="Aktuálna strana v SLK"; 
$LANG['buttons'][29]="Všetky strany v PDF"; 
$LANG['buttons'][30]="Všetky strany v SLK"; 
$LANG['buttons'][31]="Export"; 
$LANG['buttons'][32]="Koniec"; 
$LANG['buttons'][33]="Štart"; 
$LANG['buttons'][34]="Zrušiť"; 
$LANG['buttons'][37]="Import"; 
$LANG['buttons'][38]="Odomknuť"; 
$LANG['buttons'][39]="Nahradiť"; 
$LANG['buttons'][40]="Zobraziť všetko"; 
$LANG['buttons'][41]="Zapnúť"; 
$LANG['buttons'][42]="Deaktivovať"; 
$LANG['buttons'][43]="Prechádzať"; 
$LANG['buttons'][44]="Aktuálna strana v CSV"; 
$LANG['buttons'][45]="Všetky strany v CSV"; 
$LANG['buttons'][46]="Pred"; 
$LANG['buttons'][47]="Potom"; 
$LANG['buttons'][48]="Premiestniť"; 
$LANG['buttons'][49]="Zachovať"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Uložiť"; 
$LANG['buttons'][52]="Otvoriť"; 
$LANG['buttons'][53]="Vyčistiť"; 
$LANG['buttons'][55]="Prvý"; 
$LANG['buttons'][56]="Posledný"; 
$LANG['buttons'][57]="Spustiť"; 
$LANG['buttons'][58]="Aktualizovať"; 
$LANG['buttons'][59]="Zrušiť priradenie"; 

$LANG['calendar'][0]="RRRR-MM-DD"; 
$LANG['calendar'][1]="DD-MM-RRRR"; 
$LANG['calendar'][2]="MM-DD-RRRR"; 

$LANG['calendarD'][0]="N"; 
$LANG['calendarD'][1]="P"; 
$LANG['calendarD'][2]="U"; 
$LANG['calendarD'][3]="S"; 
$LANG['calendarD'][4]="Š"; 
$LANG['calendarD'][5]="Pi"; 
$LANG['calendarD'][6]="So"; 

$LANG['calendarDay'][0]="Nedeľa"; 
$LANG['calendarDay'][1]="Pondelok"; 
$LANG['calendarDay'][2]="Utorok"; 
$LANG['calendarDay'][3]="Streda"; 
$LANG['calendarDay'][4]="Štvrtok"; 
$LANG['calendarDay'][5]="Piatok"; 
$LANG['calendarDay'][6]="Sobota"; 

$LANG['calendarM'][0]="Január"; 
$LANG['calendarM'][1]="Február"; 
$LANG['calendarM'][2]="Marec"; 
$LANG['calendarM'][3]="Apríl"; 
$LANG['calendarM'][4]="Máj"; 
$LANG['calendarM'][5]="Jún"; 
$LANG['calendarM'][6]="Júl"; 
$LANG['calendarM'][7]="August"; 
$LANG['calendarM'][8]="September"; 
$LANG['calendarM'][9]="Október"; 
$LANG['calendarM'][10]="November"; 
$LANG['calendarM'][11]="December"; 

$LANG['cartridges'][0]="Tonerová náplň"; 
$LANG['cartridges'][7]="Nebola nájdena žiadna tonerová náplň"; 
$LANG['cartridges'][9]="Žiadna tonerová náplň"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Typ náplne"; 
$LANG['cartridges'][13]="Nová"; 
$LANG['cartridges'][14]="Použité"; 
$LANG['cartridges'][15]="Opotrebované"; 
$LANG['cartridges'][16]="Náplň(e)"; 
$LANG['cartridges'][20]="Nová"; 
$LANG['cartridges'][21]="Použité"; 
$LANG['cartridges'][22]="Opotrebované"; 
$LANG['cartridges'][24]="Pridať dátum"; 
$LANG['cartridges'][27]="Na"; 
$LANG['cartridges'][29]="Koniec životnosti"; 
$LANG['cartridges'][32]="Modely kompatibilných tlačiarní"; 
$LANG['cartridges'][33]="Použité tonerové náplne"; 
$LANG['cartridges'][34]="Nie je voľná tonerová náplň"; 
$LANG['cartridges'][35]="Použité tonerové náplne"; 
$LANG['cartridges'][37]="Páska"; 
$LANG['cartridges'][39]="Počítadlo tlačiarne"; 
$LANG['cartridges'][40]="Priemerný čas uskladnenia v inventári"; 
$LANG['cartridges'][41]="Priemerný čas použitia"; 
$LANG['cartridges'][42]="Priemerný počet vytlačených stránok"; 

$LANG['central'][2]="Posledné"; 
$LANG['central'][4]="Udalosti nie sú"; 
$LANG['central'][5]="Domov"; 
$LANG['central'][6]="Odhlásiť sa"; 
$LANG['central'][7]="Nápoveda"; 
$LANG['central'][8]="Prílohy"; 
$LANG['central'][9]="Vaše požiadavky v procese spracovania"; 
$LANG['central'][10]="Nové požiadavky"; 
$LANG['central'][12]="Vlastné zobrazenie"; 
$LANG['central'][13]="Globálne zobrazenie"; 
$LANG['central'][14]="Skupinové zobrazenie"; 
$LANG['central'][18]="Požiadavky na uzavretie"; 
$LANG['central'][19]="Požiadavky na overenie"; 

$LANG['choice'][0]="Nie"; 
$LANG['choice'][1]="Áno"; 

$LANG['common'][0]="Bez názvu"; 
$LANG['common'][1]="Položka"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Zobraziť kôš"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Výrobca"; 
$LANG['common'][6]="Názov šablony"; 
$LANG['common'][7]="Zvoliť šablónu"; 
$LANG['common'][8]="Spravovať šablóny..."; 
$LANG['common'][9]="Pridať šablónu..."; 
$LANG['common'][10]="Zodpovedný technik"; 
$LANG['common'][11]="Obmedzené zobrazenie"; 
$LANG['common'][12]="Nastavenia"; 
$LANG['common'][13]="Šablóna"; 
$LANG['common'][14]="Šablóny"; 
$LANG['common'][15]="Umiestnenie"; 
$LANG['common'][16]="Názov"; 
$LANG['common'][17]="Typ"; 
$LANG['common'][18]="Alternatívne úžívateľské meno"; 
$LANG['common'][19]="Sériové číslo"; 
$LANG['common'][20]="Inventárne číslo"; 
$LANG['common'][21]="Číslo alternatívneho úžívateľskeho mena"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operácia bola úspešná"; 
$LANG['common'][24]="Nie je vybratý element alebo je zle definovaná operácia"; 
$LANG['common'][25]="Komentáre"; 
$LANG['common'][26]="Posledná aktualizácia"; 
$LANG['common'][27]="Dátum"; 
$LANG['common'][28]="Zmazané"; 
$LANG['common'][29]="Pluginy"; 
$LANG['common'][30]="Nová položka"; 
$LANG['common'][31]="Prázdna šablóna"; 
$LANG['common'][32]="Charakteristika"; 
$LANG['common'][33]="Celkom"; 
$LANG['common'][34]="Užívateľ"; 
$LANG['common'][35]="Skupina"; 
$LANG['common'][36]="Kategória (trieda)"; 
$LANG['common'][37]="Autor"; 
$LANG['common'][38]="Odglobalizovať"; 
$LANG['common'][39]="Zdvojiť položku toľkokrát, koľko je pripojení"; 
$LANG['common'][40]="Naozaj si prajete deglobalizovať túto premennú?"; 
$LANG['common'][41]="Emailové upozornenia"; 
$LANG['common'][42]="Mobilný telefón"; 
$LANG['common'][43]="Meno"; 
$LANG['common'][44]="Východzia(e) hodnota(y)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Postup"; 
$LANG['common'][48]="Priezvisko"; 
$LANG['common'][49]="Žiadne"; 
$LANG['common'][50]="Potvrdiť nenávratné zmazanie?"; 
$LANG['common'][51]="Celé meno"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Zoznam"; 
$LANG['common'][54]="Položka nenájdená"; 
$LANG['common'][55]="Naozaj si prajete zmazať tento prvok?"; 
$LANG['common'][56]="Štandardné rozhranie"; 
$LANG['common'][57]="Titulok"; 
$LANG['common'][58]="Maximálna hodnota"; 
$LANG['common'][59]="Globálne"; 
$LANG['common'][60]="Aktívne"; 
$LANG['common'][61]="Neznáma chyba"; 
$LANG['common'][62]="Iné"; 
$LANG['common'][63]="Chyba(y)"; 
$LANG['common'][64]="Správca"; 
$LANG['common'][65]="Rozhranie"; 
$LANG['common'][66]="Všetko"; 
$LANG['common'][67]="Ostatné"; 
$LANG['common'][68]="Na šírku"; 
$LANG['common'][69]="Na výšku"; 
$LANG['common'][70]="Položka bola pridaná"; 
$LANG['common'][71]="Položka bola aktualizovaná"; 
$LANG['common'][72]="Položka bola odstránená"; 
$LANG['common'][73]="Položka bola vynulovaná"; 
$LANG['common'][74]="Položka úspešne obnovená"; 
$LANG['common'][75]="Nemáte oprávnenie vytvoriť túto položku rekurzívne v tomto subjekte"; 
$LANG['common'][76]="Verejné"; 
$LANG['common'][77]="Osobné"; 
$LANG['common'][78]="Nastaviť verejné"; 
$LANG['common'][79]="Nastaviť osobné"; 
$LANG['common'][80]="Nahrávam..."; 
$LANG['common'][81]="Nezobrazovať zmazané položky"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="Nemáte dostatočné oprávnenie na vykonanie tejto akcie."; 
$LANG['common'][84]="Zmena indikátora zakázaná. Existujú prepojené položky.."; 
$LANG['common'][85]="Zmena viditeľnosti v podriadených subjektoch"; 
$LANG['common'][86]="Nemôžete meniť vlastnosti viditeľnosť pre zdedené subjekty."; 
$LANG['common'][87]="Nová karta"; 
$LANG['common'][88]="Vlastné"; 
$LANG['common'][89]="Neinštalované"; 
$LANG['common'][90]="Objekt"; 
$LANG['common'][91]="Nemožno meniť tento atribút. Je zdedený po svojom rodičovi."; 
$LANG['common'][92]="Alternatívne úžívateľské meno"; 
$LANG['common'][93]="Nové zdedené záhlavie"; 

$LANG['computers'][0]="Jednotka"; 
$LANG['computers'][1]="Voľné %"; 
$LANG['computers'][2]="Voľné miesto"; 
$LANG['computers'][3]="Hlavná veľkosť"; 
$LANG['computers'][4]="Súborový systém"; 
$LANG['computers'][5]="Prípojný bod"; 
$LANG['computers'][6]="Partícia"; 
$LANG['computers'][7]="Pridať jednotku"; 
$LANG['computers'][8]="Jednotky"; 
$LANG['computers'][9]="Operačný systém"; 
$LANG['computers'][10]="Sériové číslo operačného systému"; 
$LANG['computers'][11]="Produktové ID operačného systému"; 
$LANG['computers'][14]="Vložené"; 
$LANG['computers'][23]="Typ pamäte"; 
$LANG['computers'][24]="Pamäť (MB)"; 
$LANG['computers'][25]="Veľkosť HDD"; 
$LANG['computers'][36]="Typ HDD"; 
$LANG['computers'][37]="Žiadny pripojený monitor"; 
$LANG['computers'][38]="Žiadna pripojená tlačiareň"; 
$LANG['computers'][39]="Tlačiarne"; 
$LANG['computers'][40]="Monitor(y)"; 
$LANG['computers'][46]="Zariadenia"; 
$LANG['computers'][47]="Žiadne pripojené zariadenie"; 
$LANG['computers'][48]="Umiestnenie bolo aktualizované. Pripojené položky boli presunuté na rovnaké umiestnenie."; 
$LANG['computers'][49]="Náhradné užívateľské meno bolo aktualizované. Pripojené položky budú zaktualizované pomocou tohoto náhradného mena."; 
$LANG['computers'][50]="Užívateľ alebo skupina aktualizovaná. Pripojené položky boli presunuté s rovnakými hodnotami."; 
$LANG['computers'][51]="Zdroj aktualizácie"; 
$LANG['computers'][52]="Verzia operačného systému"; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="Žiadny telefón nie je pripojený"; 
$LANG['computers'][55]="Telefón(y)"; 
$LANG['computers'][56]="Stav aktualizovaný. Pripojené položky boli aktualizované použitím tohoto stavu."; 

$LANG['connect'][0]="Priame pripojenia"; 
$LANG['connect'][1]="Nepripojené."; 
$LANG['connect'][15]="Automatická aktualizácia nasledujúcich položiek"; 
$LANG['connect'][16]="Upozornenie!!! Nasledujúce dve HW položky nesúhlasia"; 

$LANG['consumables'][0]="Spotrebný materiál"; 
$LANG['consumables'][1]="Vo fonde"; 
$LANG['consumables'][2]="Referencia"; 
$LANG['consumables'][7]="Nebol nájdený žiaden spotrebný tovar"; 
$LANG['consumables'][9]="Žiaden spotrebný materiál"; 
$LANG['consumables'][12]="Typ spotrebného materiálu"; 
$LANG['consumables'][13]="Nová"; 
$LANG['consumables'][15]="Použité"; 
$LANG['consumables'][16]="Spotrebný materiál"; 
$LANG['consumables'][20]="Nová"; 
$LANG['consumables'][22]="Použité"; 
$LANG['consumables'][23]="Stav"; 
$LANG['consumables'][26]="Použiť dátum"; 
$LANG['consumables'][32]="Dať"; 
$LANG['consumables'][35]="Použitý spotrebný tovar"; 
$LANG['consumables'][36]="Umiestnenie inventára"; 
$LANG['consumables'][37]="Späť na inventár"; 
$LANG['consumables'][38]="Prah upozornenia"; 

$LANG['contract'][0]="Zmluva je expirovaná od"; 
$LANG['contract'][1]="Zmluva s poznámkou od"; 

$LANG['crontask'][0]="Automatické akcie"; 
$LANG['crontask'][1]="Synchronizácia príslušenstva z OCSNG"; 
$LANG['crontask'][2]="Poslať upozornenie o cartidgoch"; 
$LANG['crontask'][3]="Poslat upozornenie o spotrebnom materiáli"; 
$LANG['crontask'][4]="Poslať upozornenia o expirovaných licenciách"; 
$LANG['crontask'][5]="Poslať upozornenia o zmluvách"; 
$LANG['crontask'][6]="Poslať upozornenia o finančných informáciách"; 
$LANG['crontask'][7]="Vyčistiť staré logy"; 
$LANG['crontask'][8]="Optimalizácia databázy"; 
$LANG['crontask'][9]="Vyžiadať email (prijímatelia pošty)"; 
$LANG['crontask'][10]="Kontrola replikácie MySQL"; 
$LANG['crontask'][11]="Kontrola nových aktualizácií"; 
$LANG['crontask'][12]="Vyčistiť expirované sessions"; 
$LANG['crontask'][13]="Vyčistiť generované grafiky"; 
$LANG['crontask'][14]="Automatické uzavretie požiadaviek"; 
$LANG['crontask'][15]="Nevyriešené požiadavky"; 
$LANG['crontask'][31]="Vypnuté"; 
$LANG['crontask'][32]="Naplánovaný"; 
$LANG['crontask'][33]="Spustený"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Mód spustenia"; 
$LANG['crontask'][37]="Frekvencia spustení"; 
$LANG['crontask'][38]="Interval spustení"; 
$LANG['crontask'][39]="Počet emailov na príjem"; 
$LANG['crontask'][40]="Posledné spustenie"; 
$LANG['crontask'][41]="Nasledovné spustenie"; 
$LANG['crontask'][42]="Čo najrýchlejšie"; 
$LANG['crontask'][43]="Žiadna akcia nie je začatá"; 
$LANG['crontask'][44]="Akcia ukončená, čiastočne spracovaná"; 
$LANG['crontask'][45]="Akcia ukončená v plnom rozsahu"; 
$LANG['crontask'][46]="Akcia ukončená, spracovanie nie je potrebné"; 
$LANG['crontask'][47]="Zoznam posledných spustení"; 
$LANG['crontask'][48]="Štart"; 
$LANG['crontask'][50]="Počet spustení"; 
$LANG['crontask'][51]="Minimálny čas"; 
$LANG['crontask'][52]="Maximálny čas"; 
$LANG['crontask'][53]="Priemerný čas"; 
$LANG['crontask'][55]="Minimálny počet"; 
$LANG['crontask'][56]="Maximálny počet"; 
$LANG['crontask'][57]="Priemerný počet"; 
$LANG['crontask'][58]="Celkový počet"; 
$LANG['crontask'][59]="Priemerná rýchlosť"; 
$LANG['crontask'][60]="Systémový zámok"; 
$LANG['crontask'][61]="Vypnutý plugin"; 
$LANG['crontask'][62]="Elementy"; 

$LANG['devices'][0]="Pridať nový komponent"; 
$LANG['devices'][1]="Pevný disk"; 
$LANG['devices'][2]="Grafická karta"; 
$LANG['devices'][3]="Sieťová karta"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Základná doska"; 
$LANG['devices'][6]="RAM"; 
$LANG['devices'][7]="Zvuková karta"; 
$LANG['devices'][19]="Disky"; 
$LANG['devices'][20]="Radiče"; 
$LANG['devices'][21]="Iné komponenty"; 
$LANG['devices'][22]="Skrinky"; 
$LANG['devices'][23]="Zdroj energie"; 
$LANG['devices'][24]="štandardne"; 
$LANG['devices'][25]="Pridať komponent"; 
$LANG['devices'][26]="Zmazanie komponentu"; 

$LANG['device_case'][0]="Veľkosť"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Možnosť zápisu"; 
$LANG['device_drive'][1]="Rýchlosť"; 

$LANG['device_hdd'][0]="rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Kapacita"; 

$LANG['device_iface'][0]="Dátový tok"; 
$LANG['device_iface'][2]="MAC adresa"; 

$LANG['device_moboard'][0]="Čipová sada"; 

$LANG['device_power'][0]="Zdroj"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvencia"; 
$LANG['device_ram'][2]="Veľkosť"; 

$LANG['document'][1]="Kontrolný súčet (SHA1)"; 
$LANG['document'][2]="Súbor"; 
$LANG['document'][3]="Hlavička"; 
$LANG['document'][4]="Typ MIME"; 
$LANG['document'][7]="Typ dokumentu"; 
$LANG['document'][9]="Rozšírenie"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Autorizované sťahovanie"; 
$LANG['document'][15]="Stiahnuť"; 
$LANG['document'][16]="Pridať dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Priradené položky"; 
$LANG['document'][21]="Priradené dokumenty"; 
$LANG['document'][22]="Aktuálny súbor"; 
$LANG['document'][23]="Súbor je priveľký, nemožno ho pridať"; 
$LANG['document'][24]="Mazanie súboru bolo úspešné"; 
$LANG['document'][25]="Chyba pri mazaní súbora"; 
$LANG['document'][26]="Súbor je platný. Upload bol úspešný."; 
$LANG['document'][27]="Možný útok pri uploade alebo bol súbor príliš veľký. Presunutie dočasného súboru zlyhalo."; 
$LANG['document'][28]="Nie je špecifikovaný súbor"; 
$LANG['document'][29]="Chyba pri vytváraní adresára"; 
$LANG['document'][30]="Overte si, že máte správne nastavené oprávnenia"; 
$LANG['document'][31]="Adresár pre dokumenty neexistuje"; 
$LANG['document'][32]="Neplatný typ súboru"; 
$LANG['document'][33]="Webový odkaz"; 
$LANG['document'][34]="Vytvoriť adresár"; 
$LANG['document'][35]="Adresár pre upload neexistuje"; 
$LANG['document'][36]="Use a FTP installed file"; 
$LANG['document'][37]="Žiadny súbor nie je k dispozícii"; 
$LANG['document'][38]="Súbor nenájdený"; 
$LANG['document'][39]="Presunutie dokumentu bolo úspešné"; 
$LANG['document'][40]="Presun súbora zlyhal"; 
$LANG['document'][41]="Kopírovanie dokumentu bolo úspešné"; 
$LANG['document'][42]="Pridané pomocou"; 
$LANG['document'][43]="Neznámy súbor"; 
$LANG['document'][44]="Neplatný názov súboru"; 
$LANG['document'][45]="Neoprávnený prístup k tomuto súboru"; 
$LANG['document'][46]="Chyba pri odosielaní súbora (pravdepodobne z dôvodu veľkosti)"; 
$LANG['document'][48]="Dokument s týmto názvom súboru už bol pripojený k (inému) záznamu"; 
$LANG['document'][49]="Súbor je zmenený (zlý kontrolný súčet)"; 
$LANG['document'][50]="Priložené položky"; 

$LANG['entity'][0]="Subjekt"; 
$LANG['entity'][2]="Root subjektu"; 
$LANG['entity'][3]="Priradiť subjektu"; 
$LANG['entity'][5]="Automatické priradenie počítača"; 
$LANG['entity'][6]="Automatické priradenie užívateľa"; 
$LANG['entity'][7]="stromová štruktúra"; 
$LANG['entity'][8]="Podľa subjektu"; 
$LANG['entity'][9]="Podriadené subjekty"; 
$LANG['entity'][10]="Vyberte požadovaný subjekt"; 
$LANG['entity'][11]="pozrieť subjekty a ich podriadené subjekty"; 
$LANG['entity'][12]="LDAP atribút identifikujúci subjekt"; 
$LANG['entity'][13]="TAG identifikujúci subjekt"; 
$LANG['entity'][14]="Rozšírené informácie"; 
$LANG['entity'][15]="LDAP adresár subjektov"; 
$LANG['entity'][16]="Vyhľadávací filter (ak je potrebný)"; 
$LANG['entity'][17]="Konfigurácia automatického uzatvárania"; 
$LANG['entity'][18]="Automatické uzatváranie požiadaviek následne"; 

$LANG['event'][0]="Položka (ID)"; 
$LANG['event'][2]="Služby"; 
$LANG['event'][3]="Úroveň"; 
$LANG['event'][4]="Správa"; 
$LANG['event'][18]="Pole"; 
$LANG['event'][19]="Aktualizovať"; 
$LANG['event'][20]="Žiadna história"; 

$LANG['financial'][1]="Zmluva"; 
$LANG['financial'][2]="Doživotne"; 
$LANG['financial'][3]="Finančné informácie"; 
$LANG['financial'][4]="Počet"; 
$LANG['financial'][5]="Cena"; 
$LANG['financial'][6]="Typ zmluvy"; 
$LANG['financial'][8]="Trvanie"; 
$LANG['financial'][9]="rok(ov)"; 
$LANG['financial'][10]="Poznámka"; 
$LANG['financial'][11]="Fakturačný interval"; 
$LANG['financial'][13]="Číslo účtu"; 
$LANG['financial'][14]="Dátum nákupu"; 
$LANG['financial'][15]="Trvanie záruky"; 
$LANG['financial'][16]="Informácie o záruke"; 
$LANG['financial'][18]="Číslo objednávky"; 
$LANG['financial'][19]="Dodací formulár"; 
$LANG['financial'][20]="Imobilizačné číslo"; 
$LANG['financial'][21]="Hodnota"; 
$LANG['financial'][22]="Typ odpisu"; 
$LANG['financial'][23]="Trvanie odpisov"; 
$LANG['financial'][24]="Pridať kontakt..."; 
$LANG['financial'][25]="Pridať dodávateľa"; 
$LANG['financial'][26]="Dodávateľ"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Pridať kontakt"; 
$LANG['financial'][36]="Pridať zmluvu"; 
$LANG['financial'][42]="Komerčný"; 
$LANG['financial'][43]="Technik"; 
$LANG['financial'][44]="Adresa"; 
$LANG['financial'][45]="Webová stránka"; 
$LANG['financial'][46]="Priradené kontakty"; 
$LANG['financial'][47]="Lineárne"; 
$LANG['financial'][48]="Klesajúci"; 
$LANG['financial'][50]="Výpožičky"; 
$LANG['financial'][51]="Úročenie"; 
$LANG['financial'][52]="Prenájmy"; 
$LANG['financial'][53]="Poistenie"; 
$LANG['financial'][54]="Hardwarová podpora"; 
$LANG['financial'][55]="Softwarová podpora"; 
$LANG['financial'][56]="Poskytované služby"; 
$LANG['financial'][57]="mesiac"; 
$LANG['financial'][59]="Prevádzkové hodiny"; 
$LANG['financial'][60]="za týždeň"; 
$LANG['financial'][61]="v sobotu"; 
$LANG['financial'][62]="Nedele a voľné dni"; 
$LANG['financial'][65]="Priradení dodávatelia"; 
$LANG['financial'][66]="Priradené zmluvy"; 
$LANG['financial'][68]="Zapnúť finančné informácie"; 
$LANG['financial'][69]="Interval obnovenia zmluvy"; 
$LANG['financial'][76]="Počiatočný dátum"; 
$LANG['financial'][77]="Odpisový koeficient"; 
$LANG['financial'][78]="Hodnota na konci záruky"; 
$LANG['financial'][79]="Typy tretích strán"; 
$LANG['financial'][80]="Záruka končí"; 
$LANG['financial'][81]="Čistá hodnota"; 
$LANG['financial'][82]="Číslo faktúry"; 
$LANG['financial'][83]="Maximálny počet položiek (0=nekonečno)"; 
$LANG['financial'][84]="Pre tento typ prvku je finančná informácia iba vzor pre prvky ktoré chcete pridať."; 
$LANG['financial'][85]="Požadovaná položka nebola nájdená"; 
$LANG['financial'][86]="Koniec zmluvy"; 
$LANG['financial'][87]="Rozpočet"; 
$LANG['financial'][88]="Platnosť do:"; 
$LANG['financial'][89]="TCO (hodnota + cena sledovania)"; 
$LANG['financial'][90]="Mesačné TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Expirované zmluvy - posledných 30 dní"; 
$LANG['financial'][94]="Zmluvy expirujúce za menej než 7 dní"; 
$LANG['financial'][95]="Zmluvy expirujúce za menej než 30 dní"; 
$LANG['financial'][96]="Zmluvy, na ktoré začalo upozorňovanie v posledných 7-ich dňoch"; 
$LANG['financial'][97]="Zmluvy, na ktoré začalo upozorňovaníe v posledných 30-tich dňoch"; 
$LANG['financial'][98]="Expirácia"; 
$LANG['financial'][99]="Dátum expirácie + poznámka"; 
$LANG['financial'][100]="PSČ"; 
$LANG['financial'][101]="Mesto"; 
$LANG['financial'][102]="Stav"; 
$LANG['financial'][103]="Krajina"; 
$LANG['financial'][104]="Priradené položky"; 
$LANG['financial'][105]="Tichý"; 
$LANG['financial'][106]="Expresne"; 
$LANG['financial'][107]="Renovácia"; 
$LANG['financial'][108]="Celkom vyčerpané z rozpočtu"; 
$LANG['financial'][109]="Celkom z rozpočtu zostáva"; 
$LANG['financial'][110]="Rozpočty"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="hodinu(ín)"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="MAtica výpočtu priority"; 
$LANG['help'][2]="Nadriadený"; 
$LANG['help'][3]="Veľmi vysoká"; 
$LANG['help'][4]="Vysoká"; 
$LANG['help'][5]="Stredný"; 
$LANG['help'][6]="Nízka"; 
$LANG['help'][7]="Veľmi nízka"; 
$LANG['help'][8]="Informovať ma o vykonaných akciách"; 
$LANG['help'][11]="Môj email"; 
$LANG['help'][14]="Odoslať správu"; 
$LANG['help'][16]="Pokiaľ chcete byť informovaný o plánovaných akciách, musíte zadať email!"; 
$LANG['help'][18]="Vaša správa bola úspešne odoslaná, vaša požiadavka bola zaznamenaná."; 
$LANG['help'][19]="Sme radi, že ste použili automatický systém helpdesk."; 
$LANG['help'][22]="Hľadať ID počítača"; 
$LANG['help'][23]="Zadajte prvé písmená (užívateľské meno, názov položky, sériové alebo výrobné číslo)"; 
$LANG['help'][24]="Typ hardware"; 
$LANG['help'][25]="Počítač"; 
$LANG['help'][26]="Sieťové zariadenie"; 
$LANG['help'][27]="Tlačiareň"; 
$LANG['help'][28]="Sledovať"; 
$LANG['help'][29]="Zariadenie"; 
$LANG['help'][30]="Všeobecná"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Telefóny"; 
$LANG['help'][40]="Nie je vyplnený názov."; 
$LANG['help'][41]="Nie je zvolená kategória."; 
$LANG['help'][42]="Veľmi vysoká"; 
$LANG['help'][43]="Vysoká"; 
$LANG['help'][44]="Stredná"; 
$LANG['help'][45]="Nízka"; 
$LANG['help'][46]="Veľmi nízka"; 
$LANG['help'][47]="Veľmi vysoká"; 
$LANG['help'][48]="Vysoká"; 
$LANG['help'][49]="Stredný"; 
$LANG['help'][50]="Nízka"; 
$LANG['help'][51]="Veľmi nízka"; 

$LANG['install'][0]="Inštalácia alebo aktualizácia GLPI"; 
$LANG['install'][1]="Pre úplne novú inštaláciu GLPI zvoľte 'Inštalácia'."; 
$LANG['install'][2]="Pre aktualizáciu z predchádzajúcej verzie GLPI zvoľte 'Aktualizovať'."; 
$LANG['install'][3]="Inštalácia"; 
$LANG['install'][4]="Aktualizovať"; 
$LANG['install'][5]="Skontrolovať kompaktabilitu vášho prostredia a systému GLPI"; 
$LANG['install'][6]="Test dokončený"; 
$LANG['install'][7]="Výsledky"; 
$LANG['install'][8]="Testovanie prekladača PHP"; 
$LANG['install'][9]="Musíte nainštalovať PHP4. Stiahnuť ho môžete tu:"; 
$LANG['install'][10]="GLPI nie je kompaktabilné s funkciou zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP je verzia 5.x a vyššia - Výborne!"; 
$LANG['install'][12]="Test session"; 
$LANG['install'][13]="Váš prekladač PHP nie je skompilovaný s podporou session!"; 
$LANG['install'][14]="Podpora session je k dispozícii - výborne!"; 
$LANG['install'][15]="Uistite sa, že bola v súbore php.ini aktivovaná podpora session"; 
$LANG['install'][16]="Kontrolujem oprávnenie na zápis pre súbory s výpismi"; 
$LANG['install'][17]="Nie je možné vytvoriť tento súbor:"; 
$LANG['install'][18]="Neoficiálne preklady sú taktiež k dispozícii"; 
$LANG['install'][19]="Súbor bol vytvorený, ale nie je ho možné zmazať."; 
$LANG['install'][20]="Vytvorenie a zmazanie súboru a adresára bolo vykonané - Výborne!"; 
$LANG['install'][21]="Kontrolujem oprávnenie na zápis pre súbory dokumentov"; 
$LANG['install'][22]="Súbor bol vytvorený - Výborne!"; 
$LANG['install'][23]="Kontrolujem oprávnenie na zápis pre súbory s nastavením"; 
$LANG['install'][24]="Inicializácia databázy"; 
$LANG['install'][25]="Pokračovať?"; 
$LANG['install'][26]="Pokračovať"; 
$LANG['install'][27]="Skúsiť znova"; 
$LANG['install'][28]="Nastavenie pripojenia k databáze"; 
$LANG['install'][29]="Parametre pripojenia k databáze"; 
$LANG['install'][30]="Server Mysql"; 
$LANG['install'][31]="Uživateľ MySQL"; 
$LANG['install'][32]="Heslo Mysql"; 
$LANG['install'][34]="Test pripojenia k databáze"; 
$LANG['install'][35]="Nemôžem sa pripojiť k databáze"; 
$LANG['install'][36]="Server odpovedal"; 
$LANG['install'][37]="Server a/alebo políčko užívateľa je prázdne"; 
$LANG['install'][38]="Zvoľte prosím databázu:"; 
$LANG['install'][39]="Vytvoriť novú databázu alebo použiť jednu z existujúcich:"; 
$LANG['install'][40]="Zvoľte prosím aktualizovanú databázu:"; 
$LANG['install'][41]="Nie je možné použiť databázu:"; 
$LANG['install'][43]="OK - databáza bola inicializovaná"; 
$LANG['install'][47]="Nie je možný zápís do súboru s nastavením databázy"; 
$LANG['install'][48]="Chyba pri vytváraní databázy!"; 
$LANG['install'][49]="Nezvolili ste databázu!"; 
$LANG['install'][50]="Kontrolujem oprávnenie na zápis pre súbory session"; 
$LANG['install'][52]="Kontrola oprávnení na zápis pre súbory automatických akcií"; 
$LANG['install'][53]="Testovanie zápisu do súboru logu"; 
$LANG['install'][55]="Inštalácia bola dokončená"; 
$LANG['install'][57]="Východzie mená/heslá sú:"; 
$LANG['install'][58]="glpi/glpi (pre účet administrátora)"; 
$LANG['install'][59]="tech/tech pre účet technika"; 
$LANG['install'][60]="normal pre bežný účet"; 
$LANG['install'][61]="post-only/post-only pre účet postonly"; 
$LANG['install'][62]="Tieto účty môžete zmazať alebo upraviť, rovnako ako počiatočné položky databázy."; 
$LANG['install'][64]="Spustiť GLPI"; 
$LANG['install'][65]="Test rozšírenia magic_quotes_sybase"; 
$LANG['install'][66]="GLPI nebude fungovať s voľbou magic_quotes_sybase; Vypnite ju prosím a skúste to znova"; 
$LANG['install'][67]="Voľba magic_quotes_sybasenie je na vašom serveri aktívna - výborne!"; 
$LANG['install'][68]="Testovanie session auto start"; 
$LANG['install'][69]="session.auto_start je aktivne. Skontrolujte súbor .htaccess v root adresári GLPI pre viac informácií."; 
$LANG['install'][70]="Nemôžem vytvoriť súbor s databázovým pripojením, overte prosím oprávnenia k súboru."; 
$LANG['install'][71]="Test rozšírenia Mysql"; 
$LANG['install'][72]="PHP musíte skompilovať s rozšírením MySQL."; 
$LANG['install'][73]="OK - funkcia  mysql_query() existuje - Výborne!"; 
$LANG['install'][74]="Test, či sa používa Session_use_trans_sid"; 
$LANG['install'][75]="V php.ini musíte deaktivovať voľbu Session_use_trans_id."; 
$LANG['install'][76]="OK - session funguje (bez problémov s trans_id) - Výborne!"; 
$LANG['install'][77]="Krok"; 
$LANG['install'][81]="Začiatok inštalácie"; 
$LANG['install'][82]="Databáza vytvorená"; 
$LANG['install'][85]="Funkcie boli nahradené - výborne!"; 
$LANG['install'][86]="Test alokovanej pamäte"; 
$LANG['install'][87]="Alokovaná pamäť:"; 
$LANG['install'][88]="Obvykle sa pre GLPI vyžaduje minimálne 64Mb."; 
$LANG['install'][89]="Výborne!"; 
$LANG['install'][90]="Skúste zvýšiť parameter memory_limit v súbore php.ini."; 
$LANG['install'][91]="Alokovaná pamäť > 64M"; 
$LANG['install'][92]="Licencia"; 
$LANG['install'][93]="Prečítal(a) som si licenčné ujednanie napísané vyššie a SÚHLASÍM s ním."; 
$LANG['install'][94]="Prečítal(a) som si licenčné ujednanie uvedené vyššie a NESÚHLASÍM s ním."; 
$LANG['install'][95]="Neobmedzená pamäť"; 
$LANG['install'][96]="Neobmedzená pamäť"; 
$LANG['install'][97]="Skontrolujte oprávnenia na zápis do adresára:"; 
$LANG['install'][99]="Kontrolujem oprávnenie na zápis pre súbory s cache pamäťou"; 
$LANG['install'][100]="Adresár nie je možné vytvoriť"; 
$LANG['install'][101]="Adresár bol vytvorený, ale nie je ho možné odstrániť."; 
$LANG['install'][102]="Test funkcií json"; 
$LANG['install'][103]="GLPI nemôže správne pracovať bez funkcií json_encode a json_decode"; 
$LANG['install'][104]="Test rozšírenia mbstring"; 
$LANG['install'][105]="Mbstring rozšírenie prekladača PHP nie je nainštalované"; 
$LANG['install'][106]="Kontrola práv na zápis pre grafické súbory"; 

$LANG['job'][2]="zadávateľ"; 
$LANG['job'][4]="Žiadateľ"; 
$LANG['job'][5]="Priradené k"; 
$LANG['job'][6]="Technik"; 
$LANG['job'][7]="Úloha"; 
$LANG['job'][8]="Posledná(é) úloha(y)"; 
$LANG['job'][9]="Sledovanie"; 
$LANG['job'][11]="Popíšte problém/akciu"; 
$LANG['job'][12]="Žiadny nasledovník tejto požiadavky."; 
$LANG['job'][13]="Nová požiadavka"; 
$LANG['job'][15]="Vyriešený"; 
$LANG['job'][19]="Sledovanie emailom"; 
$LANG['job'][20]="Doba trvania celkom"; 
$LANG['job'][21]="Hodina(y)"; 
$LANG['job'][22]="Minút"; 
$LANG['job'][29]="Pridať nové sledovanie"; 
$LANG['job'][30]="Pridať novú úlohu"; 
$LANG['job'][31]="Trvanie"; 
$LANG['job'][32]="Žiadny"; 
$LANG['job'][33]="Vyprázdniť popis"; 
$LANG['job'][34]="Naplánovať sledovanie položky"; 
$LANG['job'][35]="Plánovanie"; 
$LANG['job'][37]="Súhrn"; 
$LANG['job'][38]="Úloha"; 
$LANG['job'][39]="Aktualizovať sledovanie"; 
$LANG['job'][40]="Časová náročnosť"; 
$LANG['job'][41]="Pevná cena"; 
$LANG['job'][42]="Cena materiálu"; 
$LANG['job'][43]="Celková cena"; 
$LANG['job'][44]="Zdroj žiadosti"; 
$LANG['job'][45]="Zdroj dôsledku"; 
$LANG['job'][46]="Požiadavka bude pridaná do subjektu"; 
$LANG['job'][47]="Ceny"; 
$LANG['job'][48]="Typ riešenia"; 
$LANG['job'][49]="Nová úloha"; 
$LANG['job'][50]="Neexistuje úloha k tejto požiadavke"; 
$LANG['job'][51]="Schválenie riešenia"; 
$LANG['job'][52]="Aktualizovať úlohu"; 
$LANG['job'][53]="Zmazanie úlohy"; 
$LANG['job'][54]="Bez opakovania, požiadavka bude potom automaticky uzatvorená"; 

$LANG['joblist'][0]="Stav"; 
$LANG['joblist'][1]="Získané úlohy"; 
$LANG['joblist'][2]="Priorita"; 
$LANG['joblist'][3]="Vlastné + skupina(y)"; 
$LANG['joblist'][4]="Priradené"; 
$LANG['joblist'][6]="Popis"; 
$LANG['joblist'][7]="Nová požiadavka k tejto položke"; 
$LANG['joblist'][8]="Žiadna úloha nebola nájdená"; 
$LANG['joblist'][9]="Nový"; 
$LANG['joblist'][10]="Uzavreté (vyriešené)"; 
$LANG['joblist'][11]="Otvorené"; 
$LANG['joblist'][12]="Uzavreté v"; 
$LANG['joblist'][13]="Požiadavky budú vykonané"; 
$LANG['joblist'][14]="Riešené"; 
$LANG['joblist'][16]="Žiadna požiadavka sa nespracováva"; 
$LANG['joblist'][17]="Uzavreté (nevyriešené)"; 
$LANG['joblist'][18]="Spracovanie (priradené)"; 
$LANG['joblist'][19]="Spracovanie (naplánované)"; 
$LANG['joblist'][21]="Spracovanie"; 
$LANG['joblist'][26]="Nevybavené"; 
$LANG['joblist'][27]="Email pre sledovanie"; 
$LANG['joblist'][28]="Požiadavky z linkovaných položiek"; 
$LANG['joblist'][29]="Dôležitosť"; 
$LANG['joblist'][30]="Dosah"; 
$LANG['joblist'][32]="Vyriešený"; 
$LANG['joblist'][33]="Uzavreté"; 
$LANG['joblist'][34]="Nevyriešené"; 
$LANG['joblist'][35]="Nie je uzavreté"; 
$LANG['joblist'][36]="Hodnota stavu v databáze"; 

$LANG['jobresolution'][1]="Riešenie"; 
$LANG['jobresolution'][3]="Schválené riešenie"; 
$LANG['jobresolution'][4]="Riešenie odmietnutia"; 
$LANG['jobresolution'][5]="Ak ste zamietli riešenie, musíte uviesť dôvod"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Umiestniť položku do verejnej časti FAQ"; 
$LANG['knowbase'][6]="Zvoľte kategóriu tejto položky:"; 
$LANG['knowbase'][7]="Zmazať túto položku z verejnej FAQ"; 
$LANG['knowbase'][8]="Upraviť túto položku"; 
$LANG['knowbase'][9]="Zmazať túto položku"; 
$LANG['knowbase'][10]="Táto položka je súčasťou verejnej časti FAQ"; 
$LANG['knowbase'][11]="Táto položka nie je súčasťou verejnej časti FAQ"; 
$LANG['knowbase'][12]="Koreňový adresár"; 
$LANG['knowbase'][13]="Názov kategórie"; 
$LANG['knowbase'][14]="Predmet"; 
$LANG['knowbase'][15]="Obsah"; 
$LANG['knowbase'][24]="Prístup k FAQ"; 
$LANG['knowbase'][26]="Zobrazenie"; 
$LANG['knowbase'][27]="Na"; 
$LANG['knowbase'][29]="Novo pridané"; 
$LANG['knowbase'][30]="Najčastejšie otázky"; 

$LANG['ldap'][0]="Hromadný import užívateľov z LDAP adresára"; 
$LANG['ldap'][1]="Synchronizovať už naimportovaných užívateľov"; 
$LANG['ldap'][2]="Importovať nových užívateľov"; 
$LANG['ldap'][3]="Žiadni užívatelia na import"; 
$LANG['ldap'][4]="Voľba adresára LDAP"; 
$LANG['ldap'][5]="Zvoľte prosím adresár LDAP, z ktorého chcete importovať užívateľov"; 
$LANG['ldap'][6]="Nemôžem sa pripojiť k adresáru LDAP"; 
$LANG['ldap'][7]="V GPLI nebol definovaný žiaden adresár LDAP"; 
$LANG['ldap'][8]="Upozornenie: Žiadosť prekročila limit adresára. Výsledky sú iba čiastočné."; 
$LANG['ldap'][9]="Test pripojenia k adresáru LDAP"; 
$LANG['ldap'][12]="Synchronizácia"; 
$LANG['ldap'][13]="v LDAP"; 
$LANG['ldap'][14]="v GLPI"; 
$LANG['ldap'][15]="Synchronizovať"; 
$LANG['ldap'][16]="Predkonfigurácia"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List LDAP repliky"; 
$LANG['ldap'][19]="Replikovať"; 
$LANG['ldap'][20]="Pridať LDAP replica"; 
$LANG['ldap'][21]="Hlavný server"; 
$LANG['ldap'][22]="Replikované"; 
$LANG['ldap'][23]="Hromadný import skupín z LDAP adresára"; 
$LANG['ldap'][24]="Import nových skupín"; 
$LANG['ldap'][25]="Žiadna skupina pre import"; 
$LANG['ldap'][30]="Ako má byť nakladané s LDAP aliasmi"; 
$LANG['ldap'][31]="Nikdy nerušiť priradenie (prednastavené)"; 
$LANG['ldap'][32]="Vždy nepriradený"; 
$LANG['ldap'][33]="Nepriradiť počas vyhľadávania (ale áno ak lokalizujem)"; 
$LANG['ldap'][34]="Nepriradené ak lokalizujem (ale áno počas vyhľadávania)"; 
$LANG['ldap'][35]="Import užívateľa"; 
$LANG['ldap'][36]="Žiadny adresár nie je priradený k subjektu: vyhľadávanie je nemožné"; 
$LANG['ldap'][38]="Vyhľadanie kritérií pre užívateľov"; 
$LANG['ldap'][39]="Rozšírené"; 
$LANG['ldap'][40]="Jednoduchý"; 
$LANG['ldap'][41]="Zmeniť"; 
$LANG['ldap'][42]="Nie je vybraný adresár"; 
$LANG['ldap'][43]="Nie sú užívatelia na synchronizáciu"; 
$LANG['ldap'][44]="Východzí server"; 
$LANG['ldap'][45]="Akcia, ak je užívateľ vymazaný z LDAP adresára"; 
$LANG['ldap'][46]="Odoberať poverenia a skupiny (dynamicky)"; 
$LANG['ldap'][47]="Presunúť do koša"; 
$LANG['ldap'][48]="Zmazaný užívateľ v adresári LDAP"; 
$LANG['ldap'][49]="Zobraziť užívateľov pridaných od"; 
$LANG['ldap'][50]="Zobraqziť užívateľov aktualizovaných od"; 
$LANG['ldap'][52]="Menší ako"; 
$LANG['ldap'][53]="Viac než"; 
$LANG['ldap'][54]="Zapnúť filtrovanie podľa dátumu"; 
$LANG['ldap'][55]="Zrušiť filtrovanie podľa dátumu"; 
$LANG['ldap'][56]="Týždne"; 

$LANG['links'][1]="Odkaz alebo názov súboru"; 
$LANG['links'][4]="Priradený typ hardwaru"; 
$LANG['links'][6]="Platné značky"; 
$LANG['links'][7]="Žiaden odkaz nebol definovaný"; 
$LANG['links'][9]="Obsah súboru"; 

$LANG['log'][1]="systém"; 
$LANG['log'][16]="plánovanie"; 
$LANG['log'][18]="komponenty"; 
$LANG['log'][20]="pridať položku"; 
$LANG['log'][21]="aktualizovať položku"; 
$LANG['log'][22]="Zmazať položku"; 
$LANG['log'][23]="Obnoviť položku"; 
$LANG['log'][24]="vyčistiť položku"; 
$LANG['log'][26]="odpojiť položku"; 
$LANG['log'][27]="pripojenie"; 
$LANG['log'][28]="Aktualizovať komponenty"; 
$LANG['log'][29]="schválenie/zamietnutie riešenia"; 
$LANG['log'][30]="priradiť typ"; 
$LANG['log'][31]="zmazanie typu"; 
$LANG['log'][32]="pridať odkaz na položku"; 
$LANG['log'][33]="zmazať odkaz s položkou"; 
$LANG['log'][34]="pridať odkaz na dodávateľa"; 
$LANG['log'][35]="zmazať odkaz s dodávateľom"; 
$LANG['log'][40]="Pripojenie IP"; 
$LANG['log'][41]="pripojenie zlyhalo"; 
$LANG['log'][42]="Rezervácia"; 
$LANG['log'][44]="Hlavička"; 
$LANG['log'][45]="Úspešné"; 
$LANG['log'][46]="Zlyhané"; 
$LANG['log'][48]="Pridať užívateľa do skupiny"; 
$LANG['log'][49]="Zmazať úžívateľa zo skupiny"; 
$LANG['log'][55]="Pripojenie"; 
$LANG['log'][59]="Automatická akcia"; 
$LANG['log'][60]="Deglobalizácia položky"; 
$LANG['log'][61]="Pridať užívateľa do subjektu"; 
$LANG['log'][62]="kompletné odstránenie tohoto užívateľa"; 
$LANG['log'][64]="modifikácia poľa"; 
$LANG['log'][65]="pravidlo"; 
$LANG['log'][66]="Bezpečnosť"; 
$LANG['log'][67]="úprava poznámok"; 
$LANG['log'][70]="pridať sieťový port"; 
$LANG['log'][71]="pridať niekoľko sieťových portov"; 
$LANG['log'][73]="zmazanie sieťového portu"; 
$LANG['log'][74]="zmazanie viacerých sieťových portov"; 
$LANG['log'][75]="sieťový port je presunutý"; 
$LANG['log'][77]="priradiť VLAN k sieťovému portu"; 
$LANG['log'][78]="priradiť VLAN k niekoľkým portom"; 
$LANG['log'][79]="VLAN odeelená od sieťového portu"; 
$LANG['log'][80]="zrušenie priradenia VLAN k viacerým sieťovým portom"; 
$LANG['log'][82]="pridať verziu"; 
$LANG['log'][83]="modifikácia verzie"; 
$LANG['log'][84]="zmazanie verzie"; 
$LANG['log'][85]="pridať licenciu"; 
$LANG['log'][86]="úprava licencie"; 
$LANG['log'][87]="vymazanie licencií"; 
$LANG['log'][88]="pridávanie cartridgov"; 
$LANG['log'][89]="pridávanie spotrebného materiálu"; 
$LANG['log'][90]="zmazanie cadridge"; 
$LANG['log'][91]="zmazanie spotrebného materiálu"; 
$LANG['log'][92]="renovácia cartridge"; 
$LANG['log'][93]="renovácia spotrebného materiálu"; 
$LANG['log'][94]="aktualizácia cartridge"; 
$LANG['log'][95]="inštalácia cartridge"; 
$LANG['log'][96]="vybratie cartridge"; 
$LANG['log'][97]="spotrebný materiál vydaný užívateľovi"; 
$LANG['log'][98]="pridať subjekt"; 
$LANG['log'][99]="modifikácia položky"; 
$LANG['log'][100]="zmazanie položky"; 

$LANG['login'][0]="Posledné prihlásenie"; 
$LANG['login'][1]="Znova sa prihlásiť"; 
$LANG['login'][2]="LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Prístup zamietnutý"; 
$LANG['login'][6]="Prihlásenie"; 
$LANG['login'][7]="Heslo"; 
$LANG['login'][8]="Prázdne prihlasovacie meno alebo heslo"; 
$LANG['login'][9]="Neautentizovaný"; 
$LANG['login'][10]="Autentifikácia"; 
$LANG['login'][11]="Užívateľ nie je autorizovaný pre pripojenie k GLPI"; 
$LANG['login'][12]="Nesprávne užívateľské meno alebo heslo."; 
$LANG['login'][13]="Políčko s heslom je prázdne"; 
$LANG['login'][14]="neznámy súbor"; 
$LANG['login'][15]="Užívateľ nenájdený alebo ich bolo nájdených viac"; 
$LANG['login'][16]="neúspešná autorizácia v LDAP"; 
$LANG['login'][18]="Interná databáza GLPI"; 
$LANG['login'][20]="NEmáte prístup k tejto aplikácii, pretože Váš účet bol deaktivovaný alebo odobraný"; 
$LANG['login'][21]="Testovacie pripojenie k serveru IMAP/POP"; 
$LANG['login'][22]="Test úspešný"; 
$LANG['login'][23]="Test zlyhal"; 
$LANG['login'][24]="Dátum posledného prihlásenia"; 
$LANG['login'][25]="Nemáte oprávnenie pre pripojenie"; 
$LANG['login'][26]="Vo vašom prehliadači musíte aktivovať funkcie JavaScriptu"; 
$LANG['login'][27]="Pre spustenie tejto aplikácie musíte povoliť cookies"; 
$LANG['login'][30]="Zmena autentifikačnej metódy"; 
$LANG['login'][31]="Autentifikácia v LDAP adresári"; 
$LANG['login'][32]="Autentifikácia v GLPI databáze"; 
$LANG['login'][33]="Autentifikácia na IMAP/POP serveri"; 

$LANG['mailgate'][0]="Príjemca e-mailu"; 
$LANG['mailgate'][2]="Vyzdvihnúť emailové požiadavky"; 
$LANG['mailgate'][3]="Počet dostupných a získaných správ"; 
$LANG['mailgate'][4]="Rozšírenie mbstring nenájdené. Upozornenie týkajúce sa použitej znakovej sady."; 
$LANG['mailgate'][5]="Nesprávny priložený súbor"; 
$LANG['mailgate'][6]="Príliš veľký priložený súbor"; 
$LANG['mailgate'][7]="Maximálna veľkosť každého súboru importovaného cez email prijímač"; 
$LANG['mailgate'][9]="Váš email nemusí byť spracovaný.\nAk problém pretrváva, kontaktujte administrátora."; 
$LANG['mailgate'][10]="Email adresát neprijal"; 
$LANG['mailgate'][11]="Vykonať import emailov"; 
$LANG['mailgate'][12]="Nemožno ovplyvniť email pre subjekt"; 
$LANG['mailgate'][13]="Dôvod odmietnutia"; 
$LANG['mailgate'][14]="Email nenájdený. Import nie je možný."; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Už hotová(é) úloha(y)"; 
$LANG['mailing'][5]="Popis požiadavky"; 
$LANG['mailing'][10]="Nová požiadavka, nasledovať"; 
$LANG['mailing'][12]="Úloha priradená"; 
$LANG['mailing'][14]="Aktualizovať kategóriu požiadavku"; 
$LANG['mailing'][15]="Aktualizovať prioritu úlohy"; 
$LANG['mailing'][17]="Aktualizovať položku požiadavky"; 
$LANG['mailing'][18]="Aktualizovať autorov požiadavky"; 
$LANG['mailing'][19]="Nová rezervácia"; 
$LANG['mailing'][20]="Aktualizovať skupinu požiadavky"; 
$LANG['mailing'][21]="Zmena v zdroji požiadavky"; 
$LANG['mailing'][23]="Úprava rezervácie"; 
$LANG['mailing'][26]="Pridaný dokument:"; 
$LANG['mailing'][27]="Aktualizovať stav požiadavky"; 
$LANG['mailing'][29]="Rezervácia zrušená"; 
$LANG['mailing'][30]="Aktualizácia úlohy"; 
$LANG['mailing'][31]="Toto je testovací email pre kontrolu systému posielania správ"; 
$LANG['mailing'][32]="Test mailu"; 
$LANG['mailing'][33]="Upozornenie o tonerových náplniach"; 
$LANG['mailing'][35]="Pre tento typ spotrebného materiálu bola dosiahnutá hodnota alarmu:"; 
$LANG['mailing'][36]="Upozornenie o spotrebnom materiáli"; 
$LANG['mailing'][37]="Zmluva zadaná v čase:"; 
$LANG['mailing'][39]="Upozornenie o zmluvách"; 
$LANG['mailing'][40]="Položka prišla na konci záruky:"; 
$LANG['mailing'][41]="Upozornenie finančných informácií"; 
$LANG['mailing'][42]="Zmena hodinovej ceny"; 
$LANG['mailing'][43]="Zmena pevnej ceny"; 
$LANG['mailing'][44]="Zmena ceny materiálu"; 
$LANG['mailing'][45]="Zmena titulu požiadavky"; 
$LANG['mailing'][46]="Zmena popisu požiadavky"; 
$LANG['mailing'][47]="Chyba pri odosielaní emailu"; 
$LANG['mailing'][48]="Zmena dátumu otvorenia"; 
$LANG['mailing'][49]="Zmena v dátume uzavretia"; 
$LANG['mailing'][50]="Zmena príjemcu požiadavky"; 
$LANG['mailing'][51]="Expirovaná licencia:"; 
$LANG['mailing'][53]="Zmena riešenia"; 
$LANG['mailing'][54]="Dátum expirácie"; 
$LANG['mailing'][100]="Kategória nie je definovaná"; 
$LANG['mailing'][101]="Sledovanie emailom bolo zapnuté"; 
$LANG['mailing'][102]="Sledovanie emailom bolo vypnuté"; 
$LANG['mailing'][104]="Trvanie sledovania"; 
$LANG['mailing'][105]="Nie je priradené"; 
$LANG['mailing'][107]="Nič"; 
$LANG['mailing'][109]="Žiadna skupina"; 
$LANG['mailing'][110]="Neplatný email"; 
$LANG['mailing'][113]="Šablóny upozornení"; 
$LANG['mailing'][114]="Telo"; 
$LANG['mailing'][115]="Hlavná časť emailu"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Výskyt"; 
$LANG['mailing'][120]="Metóda upozornenia"; 
$LANG['mailing'][121]="Príjemcovia"; 
$LANG['mailing'][122]="Úloha je už ukončená"; 
$LANG['mailing'][123]="Vyriešená požiadavka"; 
$LANG['mailing'][124]="Pridať novú lokalizáciu"; 
$LANG['mailing'][125]="Východzí preklad"; 
$LANG['mailing'][126]="Preklad šablóny"; 
$LANG['mailing'][127]="Uzavretie požiadavky"; 
$LANG['mailing'][128]="ponechať prázdne pole pre údaje z HTML"; 
$LANG['mailing'][129]="Zmazanie požiadavky"; 
$LANG['mailing'][130]="Od"; 
$LANG['mailing'][131]="Príjemca"; 
$LANG['mailing'][132]="Hlavička emailu"; 
$LANG['mailing'][133]="Vymazať email(y)"; 
$LANG['mailing'][134]="Aktualizovať urgenciu"; 
$LANG['mailing'][135]="Vymazanie sledovania"; 
$LANG['mailing'][136]="Rezervácia expirovala"; 
$LANG['mailing'][137]="Užívateľ hardware"; 
$LANG['mailing'][138]="Zoznam možných označení"; 
$LANG['mailing'][139]="Návestie"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Sledovania"; 
$LANG['mailing'][142]="Úlohy"; 
$LANG['mailing'][143]="Kontroly platnosti"; 
$LANG['mailing'][144]="Historicky"; 
$LANG['mailing'][145]="Zoznam hodnôt"; 
$LANG['mailing'][146]="Samostatná hodnota"; 
$LANG['mailing'][147]="Možná(é) hodnota(y)"; 

$LANG['Menu'][0]="Počítače"; 
$LANG['Menu'][1]="Siete"; 
$LANG['Menu'][2]="Tlačiarne"; 
$LANG['Menu'][3]="Monitory"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Požiadavky"; 
$LANG['Menu'][6]="Správy"; 
$LANG['Menu'][11]="Nastavenia"; 
$LANG['Menu'][12]="Údržba"; 
$LANG['Menu'][13]="Štatistika"; 
$LANG['Menu'][14]="Užívatelia"; 
$LANG['Menu'][15]="Administrácia"; 
$LANG['Menu'][16]="Zariadenia"; 
$LANG['Menu'][17]="Rezervácie"; 
$LANG['Menu'][18]="Nástroje"; 
$LANG['Menu'][19]="Databáza znalostí"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Tonerové náplne"; 
$LANG['Menu'][22]="Kontakty"; 
$LANG['Menu'][23]="Dodávatelia"; 
$LANG['Menu'][24]="Finančné informácie"; 
$LANG['Menu'][25]="Zmluvy"; 
$LANG['Menu'][26]="Správa"; 
$LANG['Menu'][27]="Dokumenty"; 
$LANG['Menu'][28]="Stav"; 
$LANG['Menu'][29]="Plánovanie"; 
$LANG['Menu'][30]="Logy"; 
$LANG['Menu'][31]="Zjednodušené rozhranie"; 
$LANG['Menu'][32]="Spotrebný materiál"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefóny"; 
$LANG['Menu'][35]="Profily"; 
$LANG['Menu'][36]="Skupiny"; 
$LANG['Menu'][37]="Subjekty"; 
$LANG['Menu'][38]="Inventár"; 
$LANG['Menu'][39]="Emailové brány"; 
$LANG['Menu'][40]="Záložky"; 
$LANG['Menu'][41]="Oprávnenia"; 

$LANG['monitors'][14]="Mikrofón"; 
$LANG['monitors'][15]="Reproduktory"; 
$LANG['monitors'][18]="Indikátory"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Veľkosť"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Sieťový port"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Sieťový port"; 
$LANG['networking'][13]="nájdený sieťový port"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Pripojené k"; 
$LANG['networking'][19]="Pridať sieťový port..."; 
$LANG['networking'][21]="Číslo portu"; 
$LANG['networking'][25]="zapnúť"; 
$LANG['networking'][37]="Nájdený sieťový port"; 
$LANG['networking'][44]="Port"; 
$LANG['networking'][46]="Pridať viac portov..."; 
$LANG['networking'][47]="Od"; 
$LANG['networking'][48]="Do"; 
$LANG['networking'][51]="Cieľ siete"; 
$LANG['networking'][55]="Priradiť VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Zvoliť MAC adresu zo zoznamu alebo ju špecifikujte nižšie"; 
$LANG['networking'][58]="Zrušiť priradenie VLAN"; 
$LANG['networking'][59]="Brána"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Podsieť"; 

$LANG['ocsconfig'][1]="Užívateľ databázy OCSweb"; 
$LANG['ocsconfig'][2]="Host pre OCSNG databázu"; 
$LANG['ocsconfig'][3]="Heslo užívateľa OCSweb"; 
$LANG['ocsconfig'][4]="Názov databázy OCS"; 
$LANG['ocsconfig'][5]="Voľby importu"; 
$LANG['ocsconfig'][6]="Ignorovať pri OCSNG importe"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Vyhechať nasledujúce tagy (oddeľovač $, nič pre všetko)"; 
$LANG['ocsconfig'][10]="Globálny import"; 
$LANG['ocsconfig'][11]="Žiaden import"; 
$LANG['ocsconfig'][12]="Importovanie jednotky"; 
$LANG['ocsconfig'][13]="Importovanie jednotky: všetko je importované 'tak ako je'"; 
$LANG['ocsconfig'][14]="Globálny import: je naiportované všetko, ale materiál je riadený globálne (bez duplikácií)"; 
$LANG['ocsconfig'][15]="Žiaden import: plugin nebude tieto prvky importovať"; 
$LANG['ocsconfig'][16]="Východzí stav"; 
$LANG['ocsconfig'][17]="Obmezdiť import nasledujúcich značiek (oddeľovač $, nič pre všetky)"; 
$LANG['ocsconfig'][18]="Najskôr skontrolujte, či sú duplikáty korektne riadené v OCSNG"; 
$LANG['ocsconfig'][19]="Jednotka importovaná podľa sériového čísla"; 
$LANG['ocsconfig'][27]="Všeobecné informácie"; 
$LANG['ocsconfig'][36]="Modemy"; 
$LANG['ocsconfig'][37]="Porty"; 
$LANG['ocsconfig'][38]="Použiť číselník softwaru OCS"; 
$LANG['ocsconfig'][39]="OCS TAG"; 
$LANG['ocsconfig'][40]="Počet počítačov pre synchronizáciu pomocou cronu"; 
$LANG['ocsconfig'][41]="Registre"; 
$LANG['ocsconfig'][43]="Administratívne informácie OCS"; 
$LANG['ocsconfig'][48]="Chovanie pri odpojení"; 
$LANG['ocsconfig'][49]="Odpad"; 
$LANG['ocsconfig'][50]="Zmazanie"; 
$LANG['ocsconfig'][52]="Automatické pripojenie počítačov"; 
$LANG['ocsconfig'][53]="Zapnúť automatický odkaz"; 
$LANG['ocsconfig'][54]="Kritériá existencie počítača"; 
$LANG['ocsconfig'][55]="Nájdi počítače v tomto stave"; 
$LANG['ocsconfig'][56]="prázdne"; 
$LANG['ocsconfig'][57]="je rovné"; 
$LANG['ocsconfig'][58]="Automaticky zlúčiť pripojenie s počítačom GLPI prostredníctvom OCS. Táto voľba je preberaná jedine synchronizačnými skriptami (nie pri práci ručne)."; 
$LANG['ocsconfig'][59]="URL adresa konzoly OCS"; 

$LANG['ocsng'][0]="Obsah NG OCS"; 
$LANG['ocsng'][1]="Synchronizovať už naimportované počítače"; 
$LANG['ocsng'][2]="Importovať nové počítače"; 
$LANG['ocsng'][3]="Vyčistiť prepojenie medzi GLPI a OCS"; 
$LANG['ocsng'][4]="Zlúčiť nový počítač OCS s aktuálnym počítačom GLPI"; 
$LANG['ocsng'][5]="Importovať nové počítače"; 
$LANG['ocsng'][6]="Automatická aktualizácia"; 
$LANG['ocsng'][7]="Importované z OCSNG"; 
$LANG['ocsng'][8]="Import bol úspěšný"; 
$LANG['ocsng'][9]="Žiadne nové počítače na import"; 
$LANG['ocsng'][10]="Počítače aktualizované v OCSNG"; 
$LANG['ocsng'][11]="Aktualizovať počítače"; 
$LANG['ocsng'][12]="Žiadne nové počítače na aktualizáciu"; 
$LANG['ocsng'][13]="Importovať dátum v GLPI"; 
$LANG['ocsng'][14]="Dátum poslednej inventarizácie v OCS"; 
$LANG['ocsng'][15]="Žiadna položka nebola zamknutá"; 
$LANG['ocsng'][16]="Zamknuté položky"; 
$LANG['ocsng'][18]="Pripojenie k databáze OCSNG bolo úspešné"; 
$LANG['ocsng'][19]="Platná verzia OCS NG"; 
$LANG['ocsng'][20]="Neplatná verzia OCS NG: vyžadovaná verzia RC3"; 
$LANG['ocsng'][21]="Pripojenie k databáze OCSNG zlyhalo"; 
$LANG['ocsng'][22]="Varovanie! Importovanými dátami (pozri vaša konfigurácia) prepíšem existujúce dáta."; 
$LANG['ocsng'][23]="Import nie je možný, počítač GLPI sa už vzťahuje k elementu OCS NG"; 
$LANG['ocsng'][24]="Vynútiť synchronizáciu"; 
$LANG['ocsng'][26]="Zvoliť server OCSNG"; 
$LANG['ocsng'][27]="Žiadne servery OCS neboli definované"; 
$LANG['ocsng'][29]="Server OCS"; 
$LANG['ocsng'][30]="Uzamknuté monitory"; 
$LANG['ocsng'][32]="Uzamknuté zariadenia"; 
$LANG['ocsng'][34]="Uzamknuté tlačiarne"; 
$LANG['ocsng'][36]="Cieľový subjekt"; 
$LANG['ocsng'][37]="Zapnúť náhľad"; 
$LANG['ocsng'][38]="Vypnúť náhľad"; 
$LANG['ocsng'][40]="Rovnaké pravidlo?"; 
$LANG['ocsng'][41]="Mód ručného importu"; 
$LANG['ocsng'][42]="Neplatná konfigurácia OCSNG (je potrebné aktivovať TRACE_DELTED)"; 
$LANG['ocsng'][43]="Prístup k databáze OCS odoprený (potrebné oprávnenie na zápis do hardware.CHECKSUM)"; 
$LANG['ocsng'][44]="Prístup k databáze OCS odoprený (potrebné oprávnenie na mazanie v tabuľke deleted_equiv)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Zmazané v OCSNG"; 
$LANG['ocsng'][47]="Spojené s počítačom OCS"; 
$LANG['ocsng'][48]="OCS ID počítača bolo zmenené"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Uzamknuté IP"; 
$LANG['ocsng'][52]="Uzamknutý software"; 
$LANG['ocsng'][54]="Software odstránený pri OCS synchronizácii"; 
$LANG['ocsng'][55]="Jednotka(y) uzamknutá(é)"; 
$LANG['ocsng'][57]="OCS Rozhranie"; 

$LANG['pager'][1]="do"; 
$LANG['pager'][2]="od"; 
$LANG['pager'][3]="v"; 
$LANG['pager'][4]="Zobraziť"; 
$LANG['pager'][5]="položiek"; 

$LANG['peripherals'][18]="Označiť"; 
$LANG['peripherals'][31]="Globálna správa"; 
$LANG['peripherals'][32]="Správa jednotky"; 
$LANG['peripherals'][33]="Typ managementu"; 

$LANG['phones'][18]="Označiť"; 
$LANG['phones'][36]="Zdroj energie"; 
$LANG['phones'][38]="Sluchátka"; 
$LANG['phones'][39]="Reproduktor"; 
$LANG['phones'][40]="Počet riadkov"; 

$LANG['planning'][0]="Požadovaný technik má už v tomto čase naplánované stretnutie."; 
$LANG['planning'][1]="Chyba pri vkladaní dát. Počiatočný dátum je novší ako koncový dátum."; 
$LANG['planning'][5]="Deň"; 
$LANG['planning'][6]="Týždeň"; 
$LANG['planning'][8]="Sledovanie"; 
$LANG['planning'][9]="Komu"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Stiahnuť kalendár vo formáte Ical"; 
$LANG['planning'][13]="webcal:// Synchronizácia"; 
$LANG['planning'][14]="Mesiac"; 
$LANG['planning'][15]="Vaše plánovanie"; 
$LANG['planning'][16]="Informácie"; 
$LANG['planning'][17]="Urobiť"; 
$LANG['planning'][18]="Hotovo"; 

$LANG['plugins'][0]="Zoznam pluginov"; 
$LANG['plugins'][2]="Inštalované / nenastavené"; 
$LANG['plugins'][3]="Inštalované / neaktivované"; 
$LANG['plugins'][4]="Chyba / vyčistiť"; 
$LANG['plugins'][5]="Neexistujúca(e) funkcia(e)"; 
$LANG['plugins'][6]="Aktualizovať"; 
$LANG['plugins'][7]="Žiaden plugin nie je nainštalovaný"; 
$LANG['plugins'][8]="Pozri katalóg pluginov"; 
$LANG['plugins'][9]="Autori"; 
$LANG['plugins'][10]="Nekompaktabilný plugin s touto verziou GPLI"; 

$LANG['printers'][14]="Sériové"; 
$LANG['printers'][15]="Paralelné"; 
$LANG['printers'][18]="Porty"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Počiatočný počet stránok"; 
$LANG['printers'][31]="Vytlačených stránok"; 

$LANG['profiles'][0]="Globálne oprávnenia"; 
$LANG['profiles'][1]="Práva subjektu"; 
$LANG['profiles'][2]="Rozhranie"; 
$LANG['profiles'][4]="Pridať sledovanie požiadavky(iek) priradenej(ých) skupine(ám)"; 
$LANG['profiles'][5]="Vytvoriť požiadavku"; 
$LANG['profiles'][6]="Pridať sledovanie mojich požiadaviek (autor)"; 
$LANG['profiles'][7]="Zobraziť všetky oznámenia"; 
$LANG['profiles'][8]="Zobraziť všetkých nasledovníkov"; 
$LANG['profiles'][9]="Zobraziť verejné odpovede"; 
$LANG['profiles'][10]="Čítať"; 
$LANG['profiles'][11]="Zapísať"; 
$LANG['profiles'][12]="Bez prístupu"; 
$LANG['profiles'][13]="Východzí profil"; 
$LANG['profiles'][14]="Zmazať požiadavku"; 
$LANG['profiles'][15]="Pridať sledovanie všetkých požiadaviek"; 
$LANG['profiles'][16]="Vlastniť požiadavku"; 
$LANG['profiles'][17]="Prevziať požiadavku"; 
$LANG['profiles'][18]="Aktualizovať oznámenie"; 
$LANG['profiles'][19]="Priradiť požiadavku"; 
$LANG['profiles'][20]="Prehliadnuť osobný plán"; 
$LANG['profiles'][21]="Prehliadnuť všetky plánovania"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Administrácia rezervácií"; 
$LANG['profiles'][24]="Aktualizovať heslo"; 
$LANG['profiles'][26]="Zobraziť oznámenia mojej skupiny"; 
$LANG['profiles'][27]="Pozrieť položky vo vlastnej skupine"; 
$LANG['profiles'][28]="Rekurzívne"; 
$LANG['profiles'][29]="Dynamicky"; 
$LANG['profiles'][30]="Zobraziť informácie OCSNG"; 
$LANG['profiles'][31]="Ručná synchronizácia OCSNG"; 
$LANG['profiles'][32]="Zobraziť priradené úlohy (osobné + skupinové)"; 
$LANG['profiles'][33]="Žiaden užívateľ nenájdený"; 
$LANG['profiles'][34]="Nadpis"; 
$LANG['profiles'][35]="Aktualizovať všetkých nasledovníkov"; 
$LANG['profiles'][36]="Pozri naplánovanie ľudí v mojej skupine"; 
$LANG['profiles'][37]="Východzí subjekt"; 
$LANG['profiles'][38]="Viditeľnosť"; 
$LANG['profiles'][39]="Priradenie"; 
$LANG['profiles'][40]="Aktualizácia"; 
$LANG['profiles'][41]="Vytvorenie"; 
$LANG['profiles'][42]="Priradenie"; 
$LANG['profiles'][43]="Užívateľské metódy autentifikácie a synchronizácie"; 
$LANG['profiles'][44]="Zmena priority"; 
$LANG['profiles'][45]="Pridať úlohu do všetkých požiadaviek"; 
$LANG['profiles'][46]="Upraviť všetky úlohy"; 
$LANG['profiles'][47]="Pridať užívateľov z externého zdroja"; 
$LANG['profiles'][48]="Vytvoriť požiadavku na schválenie"; 
$LANG['profiles'][49]="Validovať požiadavku"; 

$LANG['registry'][1]="Hromada"; 
$LANG['registry'][2]="Cesta"; 
$LANG['registry'][3]="Kľúč/hodnota"; 
$LANG['registry'][4]="Kľúče registra nájdené"; 
$LANG['registry'][5]="Žiaden kľúč nebol v registri nájdený"; 
$LANG['registry'][6]="Názov OCS"; 

$LANG['reminder'][0]="Vlastné poznámky"; 
$LANG['reminder'][1]="Verejné poznámky"; 
$LANG['reminder'][6]="Nová poznámka"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Pridať do plánovača"; 
$LANG['reminder'][15]="Bez titulu"; 
$LANG['reminder'][16]="Globálne poznámky"; 

$LANG['reports'][0]="Zvoľte správu, ktorú chcete vygenerovať"; 
$LANG['reports'][4]="Zoznam hardware v zmluve"; 
$LANG['reports'][11]="Hardware súčasťou zmluvy"; 
$LANG['reports'][12]="Typ hardware"; 
$LANG['reports'][13]="Dátum(y)"; 
$LANG['reports'][15]="Zobraziť správu"; 
$LANG['reports'][19]="Alternatívne úžívateľské meno"; 
$LANG['reports'][26]="Východzia správa"; 
$LANG['reports'][27]="Podľa zmluvy"; 
$LANG['reports'][28]="Podľa roku"; 
$LANG['reports'][33]="Správa o sieti"; 
$LANG['reports'][36]="Pripojené zariadenia"; 
$LANG['reports'][37]="Ponuky"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Podľa umiestnenia"; 
$LANG['reports'][41]="Podľa hardware"; 
$LANG['reports'][42]="Podľa sieťovej priepuste"; 
$LANG['reports'][46]="hardwarové porty"; 
$LANG['reports'][47]="porty zariadenia"; 
$LANG['reports'][49]="Správa o sieti podľa pripojenia"; 
$LANG['reports'][51]="Správa o sieti podľa položiek"; 
$LANG['reports'][52]="prepínač"; 
$LANG['reports'][54]="Správa o sieti podľa umiestnenia"; 
$LANG['reports'][57]="Zoznam materiálu"; 
$LANG['reports'][58]="Správa o vybavení za rok"; 
$LANG['reports'][60]="Dátum otvorenia"; 
$LANG['reports'][61]="Dátum uzavretia"; 
$LANG['reports'][62]="Finančné informácie o hardware"; 
$LANG['reports'][63]="Iné informácie o financiách (licencie, náplne, spotrebný materiál)"; 
$LANG['reports'][64]="Dátum vyriešenia"; 

$LANG['reservation'][1]="Zazmluvniteľných položiek"; 
$LANG['reservation'][2]="Zariadenie nie je dočasne k dispozícii"; 
$LANG['reservation'][3]="Kliknite pre zneprístupnenie"; 
$LANG['reservation'][5]="Kliknite pre sprístupnenie"; 
$LANG['reservation'][6]="Pre autorizáciu výpožičky kliknite"; 
$LANG['reservation'][7]="Autorizovať výpožičky"; 
$LANG['reservation'][8]="Zapísať"; 
$LANG['reservation'][9]="Zapísať položku"; 
$LANG['reservation'][16]="Do"; 
$LANG['reservation'][17]="Od"; 
$LANG['reservation'][18]="Požadovaná položka je v tomto momente už rezervovaná."; 
$LANG['reservation'][20]="Späť na plánovanie"; 
$LANG['reservation'][21]="Pozrieť sa na rezervácie"; 
$LANG['reservation'][22]="Upraviť komentár"; 
$LANG['reservation'][25]="Hardware na zapožičanie"; 
$LANG['reservation'][27]="Pravidelnosť"; 
$LANG['reservation'][28]="Podľa týždňa"; 
$LANG['reservation'][29]="Podľa dňa"; 
$LANG['reservation'][30]="lehoty"; 
$LANG['reservation'][31]="od"; 
$LANG['reservation'][35]="Aktuálne a budúce rezervácie"; 
$LANG['reservation'][36]="Posledná rezervácia"; 
$LANG['reservation'][37]="Žiadna rezervácia"; 
$LANG['reservation'][38]="Skutočne si prajete zmazať túto položku zo zoznamu výpožičiek?"; 
$LANG['reservation'][39]="Odstráni všetky rezervácie, na ktorých sa pracuje."; 
$LANG['reservation'][40]="Dnes expirujúce rezervácie materiálu"; 

$LANG['rulesengine'][0]="je"; 
$LANG['rulesengine'][1]="nie je"; 
$LANG['rulesengine'][2]="obsahuje"; 
$LANG['rulesengine'][3]="neobsahuje"; 
$LANG['rulesengine'][4]="začína s"; 
$LANG['rulesengine'][5]="ukončil"; 
$LANG['rulesengine'][6]="Kritérium"; 
$LANG['rulesengine'][7]="Akcie"; 
$LANG['rulesengine'][8]="Správa pravidiel"; 
$LANG['rulesengine'][9]="Logický operátor"; 
$LANG['rulesengine'][10]="Pozícia"; 
$LANG['rulesengine'][11]="Typ akcie"; 
$LANG['rulesengine'][12]="Polia"; 
$LANG['rulesengine'][13]="Hodnota"; 
$LANG['rulesengine'][14]="Podmienka"; 
$LANG['rulesengine'][15]="Dôvod"; 
$LANG['rulesengine'][16]="Kritérium"; 
$LANG['rulesengine'][17]="Pravidlá"; 
$LANG['rulesengine'][18]="Pravidlá pre prevod počítača na objekt"; 
$LANG['rulesengine'][19]="Pravidlá priradenia subjektov a práv"; 
$LANG['rulesengine'][20]="Pravidlá aplikované"; 
$LANG['rulesengine'][21]="Pravidlá aplikovateľné na podriadené subjekty"; 
$LANG['rulesengine'][22]="Priradiť"; 
$LANG['rulesengine'][23]="Lokálne pravidlá"; 
$LANG['rulesengine'][24]="Typ pravidla"; 
$LANG['rulesengine'][25]="Názov počítača"; 
$LANG['rulesengine'][26]="Skontrolovať regulárny výraz"; 
$LANG['rulesengine'][27]="regulárny výraz neodpovedá"; 
$LANG['rulesengine'][28]="Obchodné pravidlá pre požiadavky"; 
$LANG['rulesengine'][29]="Zoznam pravidiel"; 
$LANG['rulesengine'][30]="Akcia"; 
$LANG['rulesengine'][33]="Číselník dropdown menu"; 
$LANG['rulesengine'][35]="Číselník software"; 
$LANG['rulesengine'][36]="Číselník výrobcov"; 
$LANG['rulesengine'][37]="Pravidlá pre priradenie programov do kategórií"; 
$LANG['rulesengine'][38]="Prepočítať"; 
$LANG['rulesengine'][40]="kategória"; 
$LANG['rulesengine'][41]="Validácia"; 
$LANG['rulesengine'][42]="AND"; 
$LANG['rulesengine'][43]="OR"; 
$LANG['rulesengine'][45]="Priradiť hodnotu z regulárneho výrazu"; 
$LANG['rulesengine'][46]="Priradiť: vybavenie podľa IP adresy"; 
$LANG['rulesengine'][47]="Priradiť: vybavenie podľa názvu + domény"; 
$LANG['rulesengine'][48]="Priradiť vybavenie"; 
$LANG['rulesengine'][49]="Priradiť: vybavenie podľa MAC adresy"; 
$LANG['rulesengine'][50]="Číselník modelov PC"; 
$LANG['rulesengine'][51]="Číselník modelov monitorov"; 
$LANG['rulesengine'][52]="Číselník modelov telefónov"; 
$LANG['rulesengine'][53]="Číselník modelov periférií"; 
$LANG['rulesengine'][54]="Číselník modelov tlačiarní"; 
$LANG['rulesengine'][55]="Číselník modelov sietí"; 
$LANG['rulesengine'][56]="Modely"; 
$LANG['rulesengine'][60]="Číselník typov PC"; 
$LANG['rulesengine'][61]="Číselník typov monitorov"; 
$LANG['rulesengine'][62]="Číselník typov telefónov"; 
$LANG['rulesengine'][63]="Číselník typov periférií"; 
$LANG['rulesengine'][64]="Číselník typov tlačiarní"; 
$LANG['rulesengine'][65]="Číselník sieťových zariadení"; 
$LANG['rulesengine'][66]="Typy"; 
$LANG['rulesengine'][67]="Číselník operačných systémov"; 
$LANG['rulesengine'][68]="Číselník Service Pack-ov"; 
$LANG['rulesengine'][69]="Číselník verzií OS"; 
$LANG['rulesengine'][70]="Pravidlá pre priradenie požiadavky sú vytvorené cez príjem pošty"; 
$LANG['rulesengine'][76]="Premenovať podľa číselníka"; 
$LANG['rulesengine'][77]="Číselníky"; 
$LANG['rulesengine'][78]="Verzia"; 
$LANG['rulesengine'][79]="Pridať výsledok z regulárneho výrazu"; 
$LANG['rulesengine'][80]="Globálny číselník"; 
$LANG['rulesengine'][81]="Výsledky pravidla"; 
$LANG['rulesengine'][82]="Detaily rozhodnutia"; 
$LANG['rulesengine'][83]="Výsledok regulérneho výrazu môžete ovplyvniť použitím reťazca #0"; 
$LANG['rulesengine'][84]="Test funkčnosti pravidiel"; 
$LANG['rulesengine'][85]="Výsledok regulárneho výrazu"; 
$LANG['rulesengine'][86]="Kategória software ovplyvnená po zmazaní software číselníkom"; 
$LANG['rulesengine'][87]="Software zmazaný GLPI číselníkom"; 
$LANG['rulesengine'][90]="V spracovaní..."; 
$LANG['rulesengine'][91]="Ukončené."; 
$LANG['rulesengine'][92]="Čakanie pred spustením premenovania podľa číselníka"; 
$LANG['rulesengine'][93]="Upozornenie! Táto operácia môže zahodiť software do koša.<br>Určite informujte vašich užívateľov."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Voľba výrobcu"; 
$LANG['rulesengine'][96]="Premenovať podľa číselníka výrobcov<br> ( ----- = Všetko)"; 
$LANG['rulesengine'][97]="Žiaden subjekt nie je k dispozícii na testovanie"; 
$LANG['rulesengine'][100]="Cache informácií"; 
$LANG['rulesengine'][102]="Názov pravidla"; 
$LANG['rulesengine'][103]="Objektov v cache"; 
$LANG['rulesengine'][104]="Pôvodná hodnota"; 
$LANG['rulesengine'][105]="Upravená hodnota"; 
$LANG['rulesengine'][106]="Nezmenené"; 
$LANG['rulesengine'][107]="Neaktívne"; 
$LANG['rulesengine'][108]="originál"; 
$LANG['rulesengine'][110]="Priradenie práv"; 
$LANG['rulesengine'][111]="Priradenie subjektov"; 
$LANG['rulesengine'][112]="Práva a priradenie subjektov"; 
$LANG['rulesengine'][120]="Zastaviť na prvom vybranom pravidle."; 
$LANG['rulesengine'][121]="Všwtky pravidlá sú vykonávané."; 
$LANG['rulesengine'][122]="Pravidlá sú použité pre nasledujúce."; 
$LANG['rulesengine'][130]="Subjekt z LDAP"; 
$LANG['rulesengine'][131]="Subjekt z TAG"; 
$LANG['rulesengine'][132]="Nie je si vedomý importu"; 
$LANG['rulesengine'][133]="Subjekt z domény"; 
$LANG['rulesengine'][134]="Odmietnuť email (bez odpovede)"; 
$LANG['rulesengine'][135]="Odmietnuť email (s odozvou na email)"; 
$LANG['rulesengine'][138]="Kritériá LDAP"; 
$LANG['rulesengine'][140]="Pridať kritérium"; 
$LANG['rulesengine'][142]="Zoznam neimportovaných emailov"; 
$LANG['rulesengine'][144]="Subjekt založený na užívateľskom profile"; 
$LANG['rulesengine'][145]="Užívateľ s jednoduchým profilom"; 
$LANG['rulesengine'][146]="Užívateľ využíva profil"; 
$LANG['rulesengine'][147]="Užívateľ podporuje jednoduchý profil"; 
$LANG['rulesengine'][148]="Poštová doména je známa"; 
$LANG['rulesengine'][150]="Pravidlá prelinkované na subjekt boli vypnuté."; 

$LANG['search'][0]="Hľadať"; 
$LANG['search'][1]="pre všetkých"; 
$LANG['search'][2]="obsahuje"; 
$LANG['search'][4]="zoradené podľa"; 
$LANG['search'][8]="Počiatočný dátum"; 
$LANG['search'][9]="Dátum ukončenia"; 
$LANG['search'][10]="v"; 
$LANG['search'][11]="Položiek nájdené"; 
$LANG['search'][12]="Označenie dátumu ukončenia"; 
$LANG['search'][15]="Položka nebola nájdená"; 
$LANG['search'][16]="Najmenší"; 
$LANG['search'][17]="Pridať vyhľadávacie kritérium"; 
$LANG['search'][18]="Zmazať kritérium vyhľadávania"; 
$LANG['search'][19]="Pridať globálne kritériá vyhľadávania"; 
$LANG['search'][20]="Zmazať globálne kritériá vyhľadávania"; 

$LANG['setup'][0]="Rozbaľovacie ponuky"; 
$LANG['setup'][2]="Pridať užívateľa..."; 
$LANG['setup'][3]="Spojenie LDAP"; 
$LANG['setup'][4]="Typy počítačov"; 
$LANG['setup'][5]="Operačné systémy"; 
$LANG['setup'][6]="Personalizácia"; 
$LANG['setup'][9]="Sieťové rozhrania"; 
$LANG['setup'][10]="Zobrazenie poradia mien a priezvisk"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Prihlásenie"; 
$LANG['setup'][19]="Heslo"; 
$LANG['setup'][20]="Potvrdenie hesla"; 
$LANG['setup'][21]="Chyba: dve heslá nie sú identické"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Vlastné sledovanie ako východzie"; 
$LANG['setup'][40]="Osobné východzie úlohy"; 
$LANG['setup'][41]="Zvoľte jazyk"; 
$LANG['setup'][42]="Typy sietí"; 
$LANG['setup'][43]="Typy tlačiarní"; 
$LANG['setup'][44]="Typy monitora"; 
$LANG['setup'][45]="Typ skrinky"; 
$LANG['setup'][46]="Východzia hodnota"; 
$LANG['setup'][47]="Prednastavený formát grafu"; 
$LANG['setup'][48]="Východzie hodnoty"; 
$LANG['setup'][62]="Zvoľte kategóriu pre konfiguráciu"; 
$LANG['setup'][63]="Varovanie: mali by ste odstrániť hlavičku použitú pre jednu alebo viac položiek"; 
$LANG['setup'][64]="Ak potvrdíte zmazanie položiek pomocou tejto hlavičky, použité polia budú vyprázdnené."; 
$LANG['setup'][65]="Môžete tiež nahradiť všetky udalosti tejto hlavičky inou:"; 
$LANG['setup'][67]="Externá autentifikácia"; 
$LANG['setup'][69]="Typy zariadení"; 
$LANG['setup'][70]="Všeobecné nastavenie"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Cieľ siete"; 
$LANG['setup'][74]="Toto umiestnenie nie je možné zmazať, pretože má pod-umiestnenie"; 
$LANG['setup'][75]="Ako potomok"; 
$LANG['setup'][79]="Kategórie požiadaviek"; 
$LANG['setup'][80]="Označenie typu tretích strán"; 
$LANG['setup'][81]="Hlavičky dokumentu"; 
$LANG['setup'][82]="Typ kontaktu"; 
$LANG['setup'][83]="Stav položky"; 
$LANG['setup'][84]="Typ náplne"; 
$LANG['setup'][85]="Typ zmluvy"; 
$LANG['setup'][86]="Typ RAM"; 
$LANG['setup'][87]="Kategórie bázy znalostí"; 
$LANG['setup'][88]="Sieť"; 
$LANG['setup'][89]="Doména"; 
$LANG['setup'][90]="VLANy"; 
$LANG['setup'][91]="Modely počítačov"; 
$LANG['setup'][92]="Typ spotrebného materiálu"; 
$LANG['setup'][93]="Rozhranie pevného disku"; 
$LANG['setup'][94]="Modely monitorov"; 
$LANG['setup'][95]="Modely siete"; 
$LANG['setup'][96]="Modely tlačiarní"; 
$LANG['setup'][97]="Modely periférií"; 
$LANG['setup'][98]="Kategória úloh"; 
$LANG['setup'][99]="Číslo budovy"; 
$LANG['setup'][100]="Miestnosť číslo"; 
$LANG['setup'][101]="MAximálny počet automatických operácií (spúšťaných cez CLI)"; 
$LANG['setup'][102]="Úroveň logovania"; 
$LANG['setup'][103]="1- Kritické (iba chyba prihlásenia)"; 
$LANG['setup'][104]="2- Vážne (Nepoužíva sa)"; 
$LANG['setup'][105]="3- Dôležité (úspešné prihlásenia)"; 
$LANG['setup'][106]="4- Poznámky (Pridať, zmazať, sledovanie)"; 
$LANG['setup'][107]="5- Komplet (Všetko)"; 
$LANG['setup'][109]="Ako dlho uchovávať logy v databáze (v dňoch, 0 pre neobmedzené)"; 
$LANG['setup'][110]="Zobraziť nové úlohy pri prihlásení"; 
$LANG['setup'][111]="Počet položiek, ktoré sa budú tlačiť na stránku"; 
$LANG['setup'][112]="Maximálny počet znakov pre každú položku zoznamu"; 
$LANG['setup'][113]="Východzí jazyk"; 
$LANG['setup'][114]="Farby priority"; 
$LANG['setup'][115]="Východzí prah pre množstvo náplne a spotrebného materiálu"; 
$LANG['setup'][116]="Automatické priradenie oznámenia technikovi"; 
$LANG['setup'][117]="Autorizovať anonymné zobrazenie FAQ"; 
$LANG['setup'][118]="Text prihlasovacej obrazovky"; 
$LANG['setup'][119]="Zobraziť"; 
$LANG['setup'][120]="Použiť Ajax"; 
$LANG['setup'][121]="Znak  rýchlej voľby plného zobrazenia rozbaľovacieho menu (wildcard)"; 
$LANG['setup'][122]="Ajax - maximálny počet prehliadnutých položiek"; 
$LANG['setup'][123]="Nepoužívať Ajax pokiaľ je počet položiek menší než (0=nikdy)"; 
$LANG['setup'][124]="Automaticky pridať užívateľa z externého autentizačného zdroja"; 
$LANG['setup'][125]="... Z externého zdroja"; 
$LANG['setup'][126]="Automaticky pridať užívateľa externého zdroja"; 
$LANG['setup'][127]="Automatické vyplnenie položiek pomocou Ajax"; 
$LANG['setup'][128]="Formát dátumu"; 
$LANG['setup'][129]="Zobraziť ID GLPI"; 
$LANG['setup'][130]="Počet dní zachovania záznamov o tejto udalosti"; 
$LANG['setup'][132]="Zobrazenie úplných mien v strome rolovacích ponúk"; 
$LANG['setup'][133]="Zapnúť OCSNG mód"; 
$LANG['setup'][134]="Mód OCSNG"; 
$LANG['setup'][135]="Normálne"; 
$LANG['setup'][136]="Preklad"; 
$LANG['setup'][137]="Ladiť"; 
$LANG['setup'][138]="Mód použitý GLPI"; 
$LANG['setup'][139]="Všeobecný"; 
$LANG['setup'][140]="Typy"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamické zobrazovanie"; 
$LANG['setup'][148]="Pokrok za hodinu"; 
$LANG['setup'][149]="Počet desatinných miest v čiastkach"; 
$LANG['setup'][150]="Formát čísla"; 
$LANG['setup'][154]="ZákladDN"; 
$LANG['setup'][155]="rootdn (pre anonymné priradenie)"; 
$LANG['setup'][156]="Prejsť (pre ne-anonymné priradenie)"; 
$LANG['setup'][157]="Rozšírenie LDAP vášho prekladača PHP nie je nainštalované"; 
$LANG['setup'][158]="Nie je možné vytvoriť pripojenie k externému zdroju LDAP"; 
$LANG['setup'][159]="Filter pripojenia"; 
$LANG['setup'][162]="Konfigurácia IMAP/POP"; 
$LANG['setup'][164]="Meno počítača IMAP/POP (užívateľský email bude mať tento tvar login@tentohostiteľ)"; 
$LANG['setup'][165]="Váš prekladač PHP bol skompilovaný bez funkcií IMAP"; 
$LANG['setup'][166]="Nie je možné vytvoriť pripojenie k externému zdroju IMAP/POP"; 
$LANG['setup'][167]="Odkazy GLPI/LDAP"; 
$LANG['setup'][168]="Možnosti pripojenia"; 
$LANG['setup'][169]="E-mail zložka (voliteľné, väčšinou INBOX)"; 
$LANG['setup'][170]="Reťazec na pripojenie"; 
$LANG['setup'][171]="Port (voliteľně)"; 
$LANG['setup'][172]="Port LDAP (východzie=389)"; 
$LANG['setup'][174]="CAS Host"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Koreňový adresár (voliteľný)"; 
$LANG['setup'][177]="CAS konfigurácia"; 
$LANG['setup'][178]="Rozšírenie CURL alebo DOMXML vášho PHP nie je nainštalované"; 
$LANG['setup'][179]="Nie je možné použiť pripojenie k externému zdroju CAS"; 
$LANG['setup'][180]="Použiť TLS"; 
$LANG['setup'][181]="ldap_start_tls neexistuje"; 
$LANG['setup'][182]="Odhlásiť pri tlačítku späť"; 
$LANG['setup'][185]="Logy v samostatných súboroch (SQL, mail, cron...)"; 
$LANG['setup'][186]="Časová zóna"; 
$LANG['setup'][190]="x509 certifikát"; 
$LANG['setup'][191]="e-mail stribút pre x509"; 
$LANG['setup'][192]="Zapnuté"; 
$LANG['setup'][193]="Premenná, ktoré obsahuje login v poli _SERVER"; 
$LANG['setup'][194]="Dodatočné informácie obdržané z LDAP adresára"; 
$LANG['setup'][195]="Zachovať stav"; 
$LANG['setup'][196]="Vyčistiť stav"; 
$LANG['setup'][197]="Kopírovať stav počítača"; 
$LANG['setup'][198]="Nastav stav"; 
$LANG['setup'][199]="Odobrať doménu v prihlasovacom formulári (login@domena)"; 
$LANG['setup'][200]="Nekonečno"; 
$LANG['setup'][201]="Konfigurácia sledovania upozornenia a emailu"; 
$LANG['setup'][202]="Zapnúť sledovanie emailom"; 
$LANG['setup'][203]="Email administrátora"; 
$LANG['setup'][204]="Podpis emailu"; 
$LANG['setup'][205]="Poslať email administrátorovi"; 
$LANG['setup'][206]="Chyba pri odoslaní emailu administrátorovi"; 
$LANG['setup'][207]="E-mail administrátora pre reply-to (ak je potrebný)"; 
$LANG['setup'][217]="Funkcia PHP mail je neznáma alebo nie je vo vašom systéme atívna"; 
$LANG['setup'][218]="Je potrebné použiť server SMTP"; 
$LANG['setup'][219]="Povoliť vytváranie anonymných požiadaviek (helpdesk.receiver)"; 
$LANG['setup'][221]="Začiatok fiškálneho roka (deň a mesiac)"; 
$LANG['setup'][223]="Obmedzenie plánovacej tabuľky"; 
$LANG['setup'][227]="Použitá základná URL adresa"; 
$LANG['setup'][228]="Prihlasovacie pole"; 
$LANG['setup'][229]="Testovací email administrátorovi"; 
$LANG['setup'][231]="Pre odoslanie správ použiť server SMTP"; 
$LANG['setup'][232]="Počítač SMTP"; 
$LANG['setup'][234]="Prihlásenie SMTP"; 
$LANG['setup'][235]="Heslo SMTP"; 
$LANG['setup'][236]="Predchádzajúci technik, ktorý mal požiadavku na starosti"; 
$LANG['setup'][237]="Administrátor"; 
$LANG['setup'][239]="Technik, ktorý má túto úlohu na starosť"; 
$LANG['setup'][240]="Voľby upozornení"; 
$LANG['setup'][241]="Žiadne osobné kritériá. Vytvoriť osobné parametre?"; 
$LANG['setup'][242]="Možnosti upozornení"; 
$LANG['setup'][243]="Upozornenia o spotrebnom materiále"; 
$LANG['setup'][244]="Upozornenia o cardridgoch"; 
$LANG['setup'][245]="Frekvencia pripomienok"; 
$LANG['setup'][246]="Upozornenia o zmluvách"; 
$LANG['setup'][247]="Upozornenia finančných informácií"; 
$LANG['setup'][248]="Skupina, ktorá má na starosti požiadavku"; 
$LANG['setup'][249]="Skupina žiadateľa"; 
$LANG['setup'][250]="Východzie zobrazenie výsledkov vyhľadávania"; 
$LANG['setup'][252]="Zvoľte východzie položky na zobrazenie"; 
$LANG['setup'][253]="Filter prehľadávania v skupinách"; 
$LANG['setup'][254]="Typ hľadania"; 
$LANG['setup'][255]="Atribút skupiny obsahujúcej jej členov"; 
$LANG['setup'][256]="V užívateľoch"; 
$LANG['setup'][257]="V skupinách"; 
$LANG['setup'][258]="Užívatelia a skupiny"; 
$LANG['setup'][259]="Patrí do skupín"; 
$LANG['setup'][260]="Atribút užívateľa obsahuje vlastnú skupinu"; 
$LANG['setup'][261]="Skupina DN"; 
$LANG['setup'][262]="Použiť DN vo vyhľadávaní"; 
$LANG['setup'][263]="Vyhľadávací filter užívateľov"; 
$LANG['setup'][264]="Upozornenia o expirovaných licenciách"; 
$LANG['setup'][271]="Obmedziť správu sledovania"; 
$LANG['setup'][272]="Obmedziť riadenie zariadenia"; 
$LANG['setup'][273]="Obmedziť správu telefónu"; 
$LANG['setup'][274]="pre ručné pridávanie"; 
$LANG['setup'][275]="Obmedziť správu tlačiarne"; 
$LANG['setup'][280]="Automatická aktualizácia častí vzťahujúcich sa k počítačom"; 
$LANG['setup'][281]="Ak sa pripojí alebo aktualizuje"; 
$LANG['setup'][282]="Ak sa odpojí"; 
$LANG['setup'][283]="Kopírovať"; 
$LANG['setup'][284]="Vyčistiť"; 
$LANG['setup'][285]="Nekopírovať"; 
$LANG['setup'][286]="Nemazať"; 
$LANG['setup'][300]="Skontrolovať dostupnosť novej verzie"; 
$LANG['setup'][301]="Nová verzia je k dispozícii:"; 
$LANG['setup'][302]="Je k dispozícii na webovej stránke GLPI: <a href='http://glpi-project' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="Máte poslednú verziu"; 
$LANG['setup'][304]="Spojenie zlyhalo. Pokiaľ používate proxy server, nastavte ho."; 
$LANG['setup'][305]="Denne"; 
$LANG['setup'][306]="Skontrolovať aktualizácie"; 
$LANG['setup'][307]="Nikdy"; 
$LANG['setup'][308]="Každý týždeň"; 
$LANG['setup'][309]="Každý mesiac"; 
$LANG['setup'][310]="Nie je možné pripojiť sa k adrese."; 
$LANG['setup'][311]="Chyba pri pripojení k proxy serveru"; 
$LANG['setup'][312]="Žiadne dáta nie sú k dispozícii na webstránke"; 
$LANG['setup'][313]="Upozornenie: toto nie je prednastavená hodnota"; 
$LANG['setup'][350]="Spojiť s položkami pre vytváranie požiadaviek."; 
$LANG['setup'][351]="Všetky položky"; 
$LANG['setup'][352]="Spojiteľné položky s požiadavkou"; 
$LANG['setup'][360]="Automatické polia (označené *)"; 
$LANG['setup'][400]="Konfigurácia proxy"; 
$LANG['setup'][407]="Odkaz nápovedy helpdesku"; 
$LANG['setup'][408]="Odkaz na hlavnú nápovedu"; 
$LANG['setup'][409]="Východzie záhlavie pri pridaní dokumentu k požiadavke"; 
$LANG['setup'][503]="Modely telefónov"; 
$LANG['setup'][504]="Typy telefónov"; 
$LANG['setup'][505]="Typ zdroja energie pri telefónoch"; 
$LANG['setup'][601]="Hodnota LDAP"; 
$LANG['setup'][602]="Pripojenie k databáze OCSNG"; 
$LANG['setup'][603]="Pridať užívateľa"; 
$LANG['setup'][604]="Priradiť k skupine"; 
$LANG['setup'][606]="Nie je možné pridať. Užívateľ už existuje."; 
$LANG['setup'][607]="Priradiť k profilu"; 
$LANG['setup'][608]="Defaultne je software viditeľný v helpdesku"; 
$LANG['setup'][609]="Nie je možné pridať. OCSNG server už existuje."; 
$LANG['setup'][610]="Vynútený titulok požiadavky"; 
$LANG['setup'][611]="Vynútený obsah požiadavky"; 
$LANG['setup'][612]="Vynútená kategória požiadavky"; 
$LANG['setup'][613]="Pridať užívateľa, ktorý nemá poverenie z LDAP adresára"; 
$LANG['setup'][614]="Nemožno aktualizovať príhlasovacie údaje. Užívateľ už existuje."; 
$LANG['setup'][615]="Životný cyklus požiadaviek"; 
$LANG['setup'][616]="Od / Komu"; 
$LANG['setup'][620]="Odkaz"; 
$LANG['setup'][621]="Vyhľadávací filter subjektov"; 
$LANG['setup'][622]="Atribút reprezentujúci subjekt"; 
$LANG['setup'][623]="Import subjektov z LDAP adresára"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Poštový server"; 
$LANG['setup'][661]="Nie je možné konfigurovať upozonenia: prosím povoľte monitoring emailom"; 
$LANG['setup'][703]="Všeobecné"; 
$LANG['setup'][704]="Upozornenie"; 
$LANG['setup'][707]="Upozornenia pri rezerváciách"; 
$LANG['setup'][708]="Upozornenia pri požiadavkách, ktoré ešte neboli riešené"; 
$LANG['setup'][720]="Systémové informácie"; 
$LANG['setup'][721]="Informácia o inštalácii systému a konfigurácii"; 
$LANG['setup'][722]="Kopírovať/vložiť do vašej žiadosti na podporu"; 
$LANG['setup'][731]="Hodnota globálnej konfigurácie"; 
$LANG['setup'][732]="Doména služieb elektronickej pošty"; 
$LANG['setup'][800]="Mysql replikácia"; 
$LANG['setup'][801]="Zapnúť MySQL replikáciu"; 
$LANG['setup'][802]="Databáza"; 
$LANG['setup'][803]="Rozdiel medzi master a slave"; 
$LANG['setup'][806]="Maximálny rozdiel medzi master a slave"; 
$LANG['setup'][807]="Podriadená databáza je nesynchronizovaná. Rozdiel je v:"; 
$LANG['setup'][808]="Podriadená databáza mimo synchronizácie!"; 
$LANG['setup'][809]="MySQL replika: iba čítať"; 
$LANG['setup'][810]="Rozsynchronizácia MySQL replikácie"; 

$LANG['software'][1]="Zakúpená verzia"; 
$LANG['software'][2]="Použiť verziu"; 
$LANG['software'][3]="Nie sú inštalované ovplyvnené licencie"; 
$LANG['software'][4]="Neobmedzene"; 
$LANG['software'][5]="Verzia"; 
$LANG['software'][6]="Vydavateľ"; 
$LANG['software'][7]="Pridať verziu"; 
$LANG['software'][8]="Pridať licenciu"; 
$LANG['software'][11]="Licencia"; 
$LANG['software'][17]="Nainštalované programy"; 
$LANG['software'][19]="Inštalácia"; 
$LANG['software'][20]="Zostávajúce"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Aktualizácia"; 
$LANG['software'][30]="Typ licencie"; 
$LANG['software'][32]="Expirácia"; 
$LANG['software'][44]="Inštalovať software"; 
$LANG['software'][45]="Odinštalovať program"; 
$LANG['software'][46]="Priraditeľné k požiadavke"; 
$LANG['software'][47]="Zlučujem"; 
$LANG['software'][48]="Spojiť"; 
$LANG['software'][49]="Software zmazaný po zlúčení"; 
$LANG['software'][50]="Priradené k počítaču"; 
$LANG['software'][51]="Počet musí byť 1 aby sa to malo význam"; 

$LANG['softwarecategories'][2]="Nerozbalené"; 
$LANG['softwarecategories'][3]="Software bez kategórie"; 
$LANG['softwarecategories'][4]="Kategorizovaný software"; 
$LANG['softwarecategories'][5]="Kategória programov"; 

$LANG['state'][0]="Stav"; 
$LANG['state'][6]="Typ položky"; 
$LANG['state'][7]="Položky neboli nájdené"; 
$LANG['state'][11]="Súhrn"; 

$LANG['stats'][0]="Zvoľte zobrazenú štatistiku"; 
$LANG['stats'][1]="Globálne"; 
$LANG['stats'][2]="Žiadna položka na zobrazenie"; 
$LANG['stats'][3]="Podľa položky"; 
$LANG['stats'][5]="Počet požiadaviek"; 
$LANG['stats'][6]="Priemerná doba riešenia problému"; 
$LANG['stats'][7]="Zobraz grafiku"; 
$LANG['stats'][11]="Počet vyriešených požiadaviek"; 
$LANG['stats'][13]="Počet požiadaviek"; 
$LANG['stats'][15]="Priemerná doba riešenia problému"; 
$LANG['stats'][16]="Meno technika"; 
$LANG['stats'][20]="Užívateľské meno"; 
$LANG['stats'][23]="Žiadna štatistika nie je k dispozícii"; 
$LANG['stats'][25]="Priemerná (skutočná) doba trvania požiadavky"; 
$LANG['stats'][27]="Celková (skutočná) doba trvania úlohy"; 
$LANG['stats'][30]="Priemerná doba trvania odpovedí na požiadavku"; 
$LANG['stats'][31]="Dni"; 
$LANG['stats'][33]="Minút"; 
$LANG['stats'][34]="Sekúnd"; 
$LANG['stats'][35]="Úloha(y)"; 
$LANG['stats'][44]="Meno dodávateľa"; 
$LANG['stats'][45]="Podľa hardware"; 
$LANG['stats'][47]="Podľa požiadavky"; 
$LANG['stats'][48]="(priradené)"; 
$LANG['stats'][49]="(nasledovať)"; 

$LANG['title'][5]="Databáza vedomostí"; 
$LANG['title'][6]="Vytváranie siete"; 
$LANG['title'][9]="Stav položky"; 
$LANG['title'][10]="Sledovanie úlohy"; 
$LANG['title'][13]="Informácie o uživateľovi"; 
$LANG['title'][14]="Externé autentizačné zdroje"; 
$LANG['title'][24]="Podpora"; 
$LANG['title'][26]="Hlavný"; 
$LANG['title'][27]="Pripojenia"; 
$LANG['title'][28]="Úlohy"; 
$LANG['title'][30]="Komponenty"; 
$LANG['title'][33]="Externé odkazy"; 
$LANG['title'][34]="Spojenie"; 
$LANG['title'][37]="Poznámky"; 
$LANG['title'][38]="História"; 
$LANG['title'][40]="Verejné a osobné poznámky"; 
$LANG['title'][42]="Hromadná modifikácia"; 
$LANG['title'][43]="Register"; 

$LANG['tracking'][1]="Moje zariadenia"; 
$LANG['tracking'][2]="Alebo kompletné vyhľadávanie"; 
$LANG['tracking'][3]="Nesprávny dátum. Akcia zrušená."; 
$LANG['tracking'][4]="Nemáte zvolenú akútnosť vo vašej požiadavke, prosím opravte to."; 
$LANG['tracking'][8]="Vaša požiadavka je bez popisu, skúste to prosím znova."; 
$LANG['tracking'][9]="Východzie pre požiadavky"; 
$LANG['tracking'][10]="Východzie pre prijímateľov emailu"; 
$LANG['tracking'][24]="Požiadavka na dokument"; 
$LANG['tracking'][29]="Počet"; 
$LANG['tracking'][30]="Nová"; 
$LANG['tracking'][31]="Spracovanie (priradené)"; 
$LANG['tracking'][32]="Spracovanie (naplánované)"; 
$LANG['tracking'][34]="Priamo"; 
$LANG['tracking'][35]="Zapísané"; 
$LANG['tracking'][37]="Uchovať požiadavky pri odstránení hardvéru z inventára"; 
$LANG['tracking'][38]="Email bol odoslaný na"; 
$LANG['tracking'][39]="Viditeľné v jednoduchom rozhraní"; 

$LANG['transfer'][1]="Premiestnenie"; 
$LANG['transfer'][3]="Ak sa už nepoužíva"; 
$LANG['transfer'][4]="Vyčistiť zoznam prvkov určených na prenos"; 
$LANG['transfer'][5]="Môžete pridať iné časti na presun alebo môžete rovno spustiť presun."; 
$LANG['transfer'][6]="Pouvažujte o vytvorení zálohy pred vlastným presunom položiek."; 
$LANG['transfer'][7]="Položky na presunutie"; 
$LANG['transfer'][8]="Mód presunu"; 

$LANG['update'][88]="Verzia vašej databázy nie je kompaktibilná s verziou nainštalovaného kódu. Vyžaduje sa aktualizácia."; 
$LANG['update'][89]="Snažíte sa použiť GLPI s verziou databázy, ktorá je určená pre vyššiu verziu. Nainštalujte prosím verziu odpovedajúcu vašej verzii."; 
$LANG['update'][90]="Chyba počas aktualizácie databázy"; 
$LANG['update'][91]="Varovanie!"; 
$LANG['update'][92]="Bude aktualizovaná databáza GLPI nazvaná:"; 
$LANG['update'][93]="Pripojenie k databáze bolo úspešné"; 
$LANG['update'][94]="Aktualizácia úspešná, vaša databáza je aktuálna"; 
$LANG['update'][95]="Pripojenie k databáze zlyhalo, overte parametre pripojenia obsiahnuté v súbore config_db.php"; 
$LANG['update'][96]="Teraz majú všetci administrátori práva 'super-admin'. Tento nový typ užívateľa bol automaticky pridaný."; 
$LANG['update'][105]="Takto nie je možné dokončiť aktualizáciu!!!"; 
$LANG['update'][106]="Návrat späť do GLPI"; 
$LANG['update'][107]="Pre aktualizáciu obsahu vašej databázy musíte pokračovať"; 
$LANG['update'][130]="Aktualizácia umiestnenia"; 
$LANG['update'][131]="Nová štruktúra je hierarchická"; 
$LANG['update'][132]="Ak ste použili oddeľovaciu značku, môžete ju nastaviť a tak automatizovať proces generovania novej štruktúry."; 
$LANG['update'][133]="Môžete tiež určiť umiestnenie rootu, ktoré bude obsahovať všetky vytvorené umiestnenia."; 
$LANG['update'][134]="Znak rozdelenia"; 
$LANG['update'][135]="Umiestnenie koreňového adresára."; 
$LANG['update'][136]="Toto je nová hierarchia. Je to OK, môžete ju potvrdiť."; 
$LANG['update'][137]="Nová štruktúra"; 
$LANG['update'][138]="Aktuálne umiestnenie"; 
$LANG['update'][139]="Optimalizácia tabuliek"; 
$LANG['update'][140]="Vytvorenie indexov"; 
$LANG['update'][141]="Zmena usporiadania databázy"; 
$LANG['update'][142]="Migrácia dát"; 

$LANG['users'][1]="Titul"; 
$LANG['users'][2]="Kategória (class)"; 

$LANG['validation'][0]="Overenie"; 
$LANG['validation'][1]="Poslať požiadavku na schválenie"; 
$LANG['validation'][2]="Stav"; 
$LANG['validation'][3]="Dátum žiadosti"; 
$LANG['validation'][4]="Dátum overenia"; 
$LANG['validation'][5]="Žiadosť o komentár"; 
$LANG['validation'][6]="Poznámka k overeniu"; 
$LANG['validation'][7]="Schválenie(a) požiadavky"; 
$LANG['validation'][9]="čakanie na schválenie"; 
$LANG['validation'][10]="Odmietnutý"; 
$LANG['validation'][11]="Povolené"; 
$LANG['validation'][12]="Žiaden subjekt na schválenie"; 
$LANG['validation'][13]="Požiadavka na schválenie odoslaná na"; 
$LANG['validation'][15]="Požiadavka čaká na vaše schválenie"; 
$LANG['validation'][16]="Voliteľne ak je schválené"; 
$LANG['validation'][18]="Žiadateľ schválenia"; 
$LANG['validation'][19]="Overenie potvrdené"; 
$LANG['validation'][20]="Overenie zamietnuté"; 
$LANG['validation'][21]="Schváliť"; 
$LANG['validation'][23]="Vybraný užívateľ nemá korektnú emailovú adresu. Žiadosť bola vytvorená, no bez potvrdenia emailom."; 
$LANG['validation'][26]="Požiadavka na schválenie"; 
$LANG['validation'][27]="Schválenie žiadosti o overenie bolo odoslané"; 
$LANG['validation'][28]="Stav požiadavky na schválenie"; 
$LANG['validation'][29]="Ak je schválenie zamietnuté, špecifikujte dôvod"; 
$LANG['validation'][30]="Zrušenie schválenia požiadavky na"; 
$LANG['validation'][31]="Aktualizovať požiadavku na schválenie na"; 
$LANG['validation'][32]="Reakcia na žiadosť o overenie bola vytvorená"; 
$LANG['validation'][33]="Požiadavky čakajúce na schválenie"; 
?>